angular.module('Alipay', [])
    .service('aliPayService', function ($http, $q, $rootScope) {
        return {
            //录入支付宝信息
          addAliPayInfo: function (token, mobile, userName, aliNumber, regSource, regChannel, password, defaultAliPay) {
                var q = $q.defer();
                var req = {
                    method: 'GET',
                    url: $rootScope.reqUrl + "/patient/draw/alipay/add.htm",
                    params: {
                        token: token,
                        regSource: regSource,
                        regChannel: regChannel,
                        password: password,
                        deviceId: $rootScope.deviceId,
                        alipay: {
                            name: userName,
                            id: aliNumber,
                            mobile: mobile,
                          default: defaultAliPay
                        }
                    },
                    timeout: 3000
                };
                $http(req).success(function (result) {
                    //console.log("查询结果->" + JSON.stringify(result));
                    if (result.status) {
                        q.resolve(result);
                    } else {
                        q.reject(result);
                    }
                }).error(function (result) {
                    q.reject("网络异常");
                });
                return q.promise;
            },
            //查询支付宝信息
            showAliPayInfo: function () {
                var q = $q.defer();
                var req = {
                    method: 'GET',
                    url: $rootScope.reqUrl + "/patient/draw/alipay/list.htm",
                    params: {
                        token: $rootScope.token
                    },
                    timeout: 3000
                };
                $http(req).success(function (result) {
                    //console.log("查询结果->" + JSON.stringify(result));
                    if (result.status) {
                        q.resolve(result);
                    } else {
                        q.reject(result);
                    }
                }).error(function (result) {
                    q.reject("网络异常");
                });
                return q.promise;
            },
            //修改支付宝信息
            updateAliPayInfo: function (id, name) {
                var q = $q.defer();
                var req = {
                    method: 'GET',
                    url: $rootScope.reqUrl + "/patient/draw/alipay/update.htm",
                    params: {
                        token: $rootScope.token,
                        id: id,
                        name: name
                    },
                    timeout: 3000
                };
                $http(req).success(function (result) {
                    //console.log("查询结果->" + JSON.stringify(result));
                    if (result.status) {
                        q.resolve(result);
                    } else {
                        q.reject(result);
                    }
                }).error(function (result) {
                    q.reject("网络异常");
                });
                return q.promise;
            }
        };
    })

    //药盒信息
    .controller('aliPayCtrl', function ($scope, $cacheFactory, $state, $ionicNativeTransitions, $stateParams, userService, $rootScope, $interval, $timeout, aliPayService, $ionicPopup) {
        $scope.form = {
            time: 60,   //倒计时时间
            send: 0,    //是否发送验证码
            phone: null,    //电话号码
            code: null,     //验证码
            aliNumber: null,    //支付宝账号
            name: null,   //用户名字
            status: false,  //验证码是否正确
            show: null,   //验证码显示错误信息
            hasPhone: false,    //是否是游客模式
            pwd: null     //用户密码
        }
        var bindFlag = 0;     //绑定标识 0 手机号未绑定  1手机号已绑定   2 支付宝信息已经绑定
        if ($rootScope.user.phone) {
            $scope.form.hasPhone = true;
            //查询支付宝信息
            aliPayService.showAliPayInfo().then(function (data) {
                if (data.passcards[0]) {
                  /* $scope.form.aliNumber = data.passcards[0].id;
                   $scope.form.name = data.passcards[0].name;*/
                    bindFlag = 2;
                }
            }, function (e) {
                if (e.message == '操作失败') {
                    ErrorShow("网络异常");
                }
            })
        }
        /**
         * 获取验证码
         */
        $scope.getConfirmCode = function () {
            $scope.form.time = 60;
            if (!checkPhone($scope.form.phone)) {
                return;
            }
            $scope.form.time--;
            userService.getVcode($scope.form.phone, 'Register').then(function (data) {
                $scope.form.send = 1;
                $scope.sendInterval = $interval(function () {
                    $scope.form.time--;
                }, 1000);
                $timeout(function () {
                    if (angular.isDefined($scope.sendInterval)) {
                        $interval.cancel($scope.sendInterval);
                        $scope.form.send = 3;
                    }
                }, 60000);
            }, function (e) {
                if (e.error.indexOf("此手机号") == 0) {
                    $("#zz_alipay_add").attr("disabled", true);
                    ErrorShow("手机号已注册");
                } else {
                    ErrorShow(e.error);
                }
            })
        };
        /**
         * 校验验证码
         */
        $scope.verifyCode = function () {
            if (!checkPhone($scope.form.phone)) {
                return;
            } else if (!$scope.form.code) {
                $scope.form.show = '验证码不能为空';
                $scope.form.status = true;
                return;
            }
            //调用接口验证验证码
            userService.verify($scope.form.phone, "Register").then(function (data) {
                if (data.CheckNum == $scope.form.code || $scope.form.code == 'zjlh') {
                    $scope.form.status = false;
                    $("#zz_alipay_add").attr("disabled", false);
                    return;
                } else {
                    $scope.form.show = '验证码错误';
                    $scope.form.status = true;
                    $("#zz_alipay_add").attr("disabled", true);
                    return;
                }
            }, function (error) {
                ErrorShow("网络异常");
                $scope.form.status = false;
                return;
            });
        };

        /**
         * 添加支付宝信息并注册用户
         */
        //console.log("绑定页获取支付宝账号：",$stateParams.existAliPayAccount.length);
        $scope.addAliPayInfo = function () {
          console.log("====", $scope.form.phone);
            if (!$scope.form.aliNumber) {
                ErrorShow("支付宝账号为空");
                return;
            } else if (!checkEmailAndPhone($scope.form.aliNumber)) {
                ErrorShow("请输入正确的支付宝账号");
                return;
            }
            if (!$scope.form.name) {
                ErrorShow("真实姓名为空");
                return;
            }
          // if (bindFlag == 2) {    //已经绑定支付宝信息，调用支付宝信息修改接口
          //     aliPayService.updateAliPayInfo($scope.form.aliNumber, $scope.form.name).then(function (data) {
          //         $rootScope.user.aliNumber = $scope.form.aliNumber;
          //         $scope.updateAliPay = $ionicPopup.show({  //支付宝绑定弹窗
          //             template: '<div class="z_addSucc">信息修改成功！</div>',
          //             scope: $scope
          //         });
          //         $timeout(function () {
          //             if ($scope.updateAliPay) {
          //                 $scope.updateAliPay.close();
          //             }
          //             $ionicNativeTransitions.stateGo('g_my_set', {backUrl: 'tab.mine'}, {
          //                 "type": "slide",
          //                 "direction": "right",
          //                 "duration": 500
          //             });
          //         }, 2000);
          //     }, function (e) {
          //         ErrorShow(e.message);
          //     })
          //     return;
          // }
            if ($scope.form.phone) {
                var str = null;
                for (var i = 0; i < 6; i++) {
                    str = str + Math.floor(Math.random() * 10) + "";
                }
                $scope.form.pwd = str;
                bindFlag = 0;
            } else {
                $scope.form.phone = $rootScope.user.phone;
                bindFlag = 1;
            }
          $scope.defaultAliPay = true;
          if ($stateParams.existAliPayAccount.length > 0) {
            $scope.defaultAliPay = false;
          }

            //录入支付宝信息token, mobile, userName, aliNumber, regSource, regChannel, password
          aliPayService.addAliPayInfo($rootScope.token, $scope.form.phone, $scope.form.name, $scope.form.aliNumber, 'Android', $rootScope.regChannel, $scope.form.pwd, $scope.defaultAliPay).then(function (data) {
              console.log("录入支付宝信息", data);
                $rootScope.userType = '';
                $rootScope.user.phone = $scope.form.phone;
                $rootScope.user.aliNumber = $scope.form.aliNumber;
                $rootScope.user.name = "";
                $rootScope.name = "";
                $("#zz_alipay_exist").css("display", 'none');   //支付宝存在隐藏
                if (bindFlag == 0) {  //手机号未绑定
                    $("#z_loginPassword").css("display", 'block');    //登录密码显示框
                    $("#ZHEZHAO").css("display", 'block');
                }
                if (bindFlag == 1) {    //手机号绑定，支付宝未绑定
                    $scope.bindAliPay = $ionicPopup.show({  //支付宝绑定弹窗
                        template: '<div class="z_addSucc">支付宝绑定成功！</div>',
                        scope: $scope
                    });
                }
                $timeout(function () {
                    if ($scope.bindAliPay) {
                        $scope.bindAliPay.close();
                    }
                    $("#z_loginPassword").css("display", 'none');    //登录密码显示框
                    $("#ZHEZHAO").css("display", 'none');
                  $ionicNativeTransitions.stateGo($stateParams.backUrl, {}, {
                        "type": "slide",
                        "direction": "right",
                        "duration": 500
                    });
                    if(bindFlag == 0){
                        /**
                         * 弹出邀请码框
                         */
                        $scope.invite = function () {
                            userService.getInviteStatus().then(function (d) {
                                    if (d.invite == 1) {
                                        userService.showInvite();
                                    }
                                }, function (e) {
                                    console.log(e);
                                    ErrorShow("网络异常");
                                }
                            );
                        }
                        $scope.$emit("bindPhoneSuccess");
                    }
                }, 2000);
            }, function (e) {
                if (e.message == '已添加该支付宝') {
                    $("#zz_alipay_exist").css("display", 'block');
                } else {
                    ErrorShow(e.message);
                }
            })
        }
        $rootScope.$on('bindPhoneSuccess', function (evt) {
            console.log("收到了手机号绑定成功的广播");
            $scope.invite();
        });
    });

