angular.module('Device', [])
  .factory('DeviceData', function ($http, $q, $rootScope) {
    return {
      /**
       * 蓝牙测量血压数据上传
       * @param ssy 收缩压
       * @param szy 舒张压
       * @param mb 脉搏
       * @returns {*}
       */
      uploadBp: function (index, up_msg, timeArr, strArr) {
        var q = $q.defer();
        var req = {
          method: 'GET',
          url: $rootScope.reqUrl + "/healthdevice/appHealthData.htm",
          params: {
            token: $rootScope.token,
            dataType: index,
            datatime: Math.ceil(new Date().getTime() / 1000),
            list: up_msg,
            timeList: timeArr,
            sleepList: strArr
          },
          timeout: 10000
        };
        $http(req).success(function (result) {
          if (result.status == 1) {
            q.resolve(result);
          } else {
            q.reject(result.message);
          }
        }).error(function (result) {
          q.reject("网络异常");
        });
        return q.promise;
      },
      queryBoxList: function () {
        var q = $q.defer();
        var req = {
          method: 'GET',
          url: $rootScope.reqUrl + "/box/query.htm",
          params: {
            userId: $rootScope.user.userId,
          },
          timeout: 5000
        };
        $http(req).success(function (result) {
          if (result.status) {
            q.resolve(result);
          } else {
            q.reject(result.message);
          }
        }).error(function (result) {
          q.reject("网络异常");
        });
        return q.promise;
      },
      queryUserInfo: function (params) {
        var q = $q.defer();
        var req = {
          method: 'GET',
          url: $rootScope.reqUrl + "/box/userInfo.htm",
          params: {
            userIds: params
          },
          timeout: 5000
        };
        $http(req).success(function (result) {
          if (result.status) {
            q.resolve(result.data);
          } else {
            q.reject(result.message);
          }
        }).error(function (result) {
          q.reject("网络异常");
        });
        return q.promise;
      },
      queryMsgList: function (deviceId) {
        var q = $q.defer();
        var req = {
          method: 'GET',
          url: $rootScope.reqUrl + "/box/message.htm",
          params: {
            deviceId: deviceId
          },
          timeout: 5000
        };
        $http(req).success(function (result) {
          if (result.status) {
            q.resolve(result);
          } else {
            q.reject(result.message);
          }
        }).error(function (result) {
          q.reject("网络异常");
        });
        return q.promise;
      },
      sendMsg: function (content, sendTo, from, deviceId) {
        var q = $q.defer();
        var req = {
          method: 'POST',
          url: $rootScope.reqUrl + "/box/sendMsg.htm",
          params: {
            content: content,
            sendTo: sendTo,
            from: from,
            deviceId: deviceId
          },
          timeout: 5000
        };
        $http(req).success(function (result) {
          if (result.status) {
            q.resolve(result);
          } else {
            q.reject(result.message);
          }
        }).error(function (result) {
          q.reject("网络异常");
        });
        return q.promise;
      },
      updateReadStatus: function (msgId) {
        var q = $q.defer();
        var req = {
          method: 'GET',
          url: $rootScope.reqUrl + "/box/msg/update.htm",
          params: {
            msgId: msgId
          },
          timeout: 5000
        };
        $http(req).success(function (result) {
          if (result.status) {
            q.resolve(result);
          } else {
            q.reject(result.message);
          }
        }).error(function (result) {
          q.reject("网络异常");
        });
        return q.promise;
      },
      queryHealthInfo: function (token, page) {
        var q = $q.defer();
        var req = {
          method: 'GET',
          url: $rootScope.reqUrl + "/open/boxdata/queryAll.htm",
          params: {
            token: token,
            page: page,
            count: 10
          },
          timeout: 5000
        };
        $http(req).success(function (result) {
          if (result.status) {
            q.resolve(result);
          } else {
            q.reject(result.message);
          }
        }).error(function (result) {
          q.reject("网络异常");
        });
        return q.promise;
      },
      updateBoxName: function (name, boxId) {
        var q = $q.defer();
        var req = {
          method: 'GET',
          url: $rootScope.reqUrl + "/box/info/update.htm",
          params: {
            name: name,
            boxId: boxId,
            userId: $rootScope.user.userId
          },
          timeout: 5000
        };
        $http(req).success(function (result) {
          if (result.status) {
            q.resolve(result);
          } else {
            q.reject(result.message);
          }
        }).error(function (e) {
          q.reject(e);
        });
        return q.promise;
      },
      deleteBox: function (boxId) {
        var q = $q.defer();
        var req = {
          method: 'get',
          url: $rootScope.reqUrl + "/box/delete.htm",
          params: {
            name: name,
            boxId: boxId,
            userId: $rootScope.user.userId
          },
          timeout: 5000
        };
        $http(req).success(function (result) {
          if (result.status) {
            q.resolve(result);
          } else {
            q.reject(result.message);
          }
        }).error(function (e) {
          q.reject(e);
        });
        return q.promise;
      }
    }
  })

  /**
   * 健康盒子
   */
  .controller('HealthBoxCtrl', function ($stateParams, $scope, $rootScope, $ionicNativeTransitions, $cacheFactory, $state, $timeout, DeviceData, $cordovaBarcodeScanner, buletoothService, $ionicPopup) {
    var cache = $cacheFactory.get($state.current.name);
    if (!cache) {
      cache = $cacheFactory($state.current.name);
    }
    cache.put('stateParams', $stateParams);

    DeviceData.queryBoxList().then(function (d) {
      console.debug(" $scope.boxes:", d);
      $scope.boxes = d.boxes;
    }, function (e) {
      console.error(e);
    });

    $scope.editAlisName = function (id) {
      $("#" + id).attr("disabled", false);
      $("#" + id).focus();
    }

    $scope.setDisable = function (id, boxId, name) {
      var alias = $("#" + id).val();
      if (alias == name) {
        return;
      }
      $("#" + id).attr("disabled", true);
      var name = $("#" + id).val();
      DeviceData.updateBoxName(name, boxId).then(function (d) {
      }, function (e) {
        console.error(e);
      });
    }

    $scope.delete = function (boxId, index) {
      var confirmPopup = $ionicPopup.confirm({
        title: '移除健康盒子',
        template: '<span class="home_dail">是否删除该盒子？</span>',
        cancelText: '取消',
        okText: '确定'

      });
      confirmPopup.then(function (res) {
        if (res) {
          $scope.boxes.splice(index, 1);
          DeviceData.deleteBox(boxId).then(function (data) {
            console.debug("data:", data);
          }, function (e) {
            console.error(e);
          });
        } else {
          console.log('You are not sure');
        }
      });
    }


    /**
     * 健康盒子详情页面
     */
    $scope.goToBoxDetail = function (boxName, userId1, userId2, currentUser, deviceId) {
      if (!userId1 && !userId2) {
        ErrorShow("盒子尚未绑定用户喔");
        return;
      }
      $ionicNativeTransitions.stateGo('g_box_news', {
        backUrl: $state.current.name,
        boxName: boxName,
        userId1: userId1,
        userId2: userId2,
        currentUser: currentUser,
        deviceId: deviceId
      }, {
        "type": "slide",
        "direction": "left",
        "duration": 500
      });
    }
    $scope.scanHealthBox = function () {
      //console.info("健康盒子扫描.........");
      $cordovaBarcodeScanner
        .scan()
        .then(function (barcodeData) {
          var qr_data = barcodeData.text;
          if (!barcodeData.cancelled) {
            buletoothService.codeSearch(qr_data).then(function (data) {
              console.debug("扫描结果:", data);
              // $scope.boxes=$scope.boxes.concat(data);
              $scope.boxes = $scope.boxes.unshift(data);
            }, function (e) {
              console.error(e);
            });

          }
        }, function (error) {
          // 扫描失败
          //alert("扫描失败");
        });
    }


    /**
     * 返回
     */
    $scope.goBack = function () {
      var param = $cacheFactory.get($stateParams.backUrl);
      var sp = null;
      if (param) {
        sp = param.get('stateParams');
        if (!sp) {
          sp = {};
        }
      } else {
        sp = {};
      }
      $ionicNativeTransitions.stateGo($stateParams.backUrl, sp, {
        "type": "slide",
        "direction": "right",
        "duration": 500
      });
    };

  })


  /**
   * 健康盒子详情页
   */
  .controller('BoxDetailCtrl', function ($stateParams, $scope, $rootScope, $ionicNativeTransitions, $cacheFactory, $state, $timeout, DeviceData) {
    //页面跳转参数存储
    var cache = $cacheFactory.get($state.current.name);
    if (!cache) {
      cache = $cacheFactory($state.current.name);
    }
    cache.put('stateParams', $stateParams);
    var cid = null;
    $scope.form = {
      title: $stateParams.boxName,
      userId1: $stateParams.userId1,
      userId2: $stateParams.userId2,
      currentUser: $stateParams.currentUser,
      cuser: null,
      deviceId: $stateParams.deviceId
    }

    var params = [];
    if ($scope.form.userId1) {
      params.push($scope.form.userId1);
    }

    if ($scope.form.userId2) {
      params.push($scope.form.userId2);
    }

    if ($scope.form.currentUser == 1) {
      cid = $scope.form.userId1;
    } else {
      cid = $scope.form.userId2;
    }

    DeviceData.queryUserInfo(params).then(function (d) {
      console.debug("用户信息':", d);
      for (var index in d.users) {
        // console.debug("d[userId]:",d[d.users[index]['id']]);
        if (cid == d.users[index].id) {
          $scope.form.cuser = d.users[index];
          d.users[index]['isCurrent'] = true;
          break;
        }
      }
      cache.put($scope.user.userId + "_boxUser", d.users);
      cache.put($scope.user.userId + "_boxUserIds", d.ids);
    }, function (e) {
      console.error(e);
    });


    /**
     * 跳转到发送消息页面
     */
    $scope.toMsgEdit = function () {
      $ionicNativeTransitions.stateGo('g_box_edit', {backUrl: $state.current.name, deviceId: $scope.form.deviceId}, {
        "type": "slide",
        "direction": "left",
        "duration": 500
      });
    }


    /**
     * 跳转到消息列表页面
     */
    $scope.goMsgList = function () {
      $ionicNativeTransitions.stateGo('g_box_nlist', {backUrl: $state.current.name, deviceId: $stateParams.deviceId}, {
        "type": "slide",
        "direction": "left",
        "duration": 500
      });
    }

    /**
     * 跳转到用户列表页面
     */
    $scope.goUserList = function () {
      $ionicNativeTransitions.stateGo('g_box_user', {backUrl: $state.current.name, boxName: $stateParams.boxName}, {
        "type": "slide",
        "direction": "left",
        "duration": 500
      });
    }

    /**
     * 用户数据页面
     */
    $scope.goHealthData = function () {
      $ionicNativeTransitions.stateGo('g_health_data', {backUrl: $state.current.name, userId: $scope.form.cuser.id}, {
        "type": "slide",
        "direction": "left",
        "duration": 500
      });
    }


    /**
     * 返回
     */
    $scope.goBack = function () {
      var param = $cacheFactory.get($stateParams.backUrl);
      var sp = null;
      if (param) {
        sp = param.get('stateParams');
        if (!sp) {
          sp = {};
        }
      } else {
        sp = {};
      }
      $ionicNativeTransitions.stateGo($stateParams.backUrl, sp, {
        "type": "slide",
        "direction": "right",
        "duration": 500
      });
    };

  })



  /**
   * 健康盒子消息列表页面
   */
  .controller('BoxMsgCtrl', function ($stateParams, $scope, $rootScope, $ionicNativeTransitions, $cacheFactory, $state, $timeout, DeviceData) {
    var cache = $cacheFactory.get($state.current.name);
    if (!cache) {
      cache = $cacheFactory($state.current.name);
    }
    cache.put('stateParams', $stateParams);
    console.debug("BoxMsgCtrl-deviceId:", $stateParams.deviceId);

    $scope.form = {
      msgList: null
    }


    DeviceData.queryMsgList($stateParams.deviceId).then(function (data) {
      $scope.form.msgList = data.messages;
      console.debug("$scope.form.msgList:", $scope.form.msgList);
    }, function (e) {
      console.error(e);
    });


    var boxCache = $cacheFactory.get($stateParams.backUrl);
    $scope.getNameById = function (id) {
      var users = boxCache.get($scope.user.userId + "_boxUser");
      for (var i = 0; i < users.length; i++) {
        if (users[i].id == id) {
          return users[i].name;
          break;
        }
      }

    }


    $rootScope.$on("SendMsg", function (event, data) {
      if (data) {
        console.debug("$scope.form.msgList:", $scope.form.msgList);
        $scope.form.msgList.unshift(data);
      }

    })


    $scope.msgDetail = function (id, title, content, time, sendTo) {
      console.debug("this.msg:", this.msg);
      var msg = this.msg;
      // if (this.msg.isRead == 0) {
      //   DeviceData.updateReadStatus(id).then(function (data) {
      //     msg.isRead = 1;
      //     console.debug("data:", data);
      //   }, function (e) {
      //     console.error(e);
      //   });
      // }

      $ionicNativeTransitions.stateGo('g_box_newdetali', {
        backUrl: $state.current.name,
        id: id,
        title: title,
        content: content,
        time: time,
        sendTo: sendTo
      }, {
        "type": "slide",
        "direction": "left",
        "duration": 500
      })
    }

    /**
     * 跳转到发送消息页面
     */
    $scope.toMsgEdit = function () {
      $ionicNativeTransitions.stateGo('g_box_edit', {backUrl: $state.current.name, deviceId: $stateParams.deviceId}, {
        "type": "slide",
        "direction": "left",
        "duration": 500
      });
    }


    /**
     * 返回
     */
    $scope.goBack = function () {
      var param = $cacheFactory.get($stateParams.backUrl);
      var sp = null;
      if (param) {
        sp = param.get('stateParams');
        if (!sp) {
          sp = {};
        }
      } else {
        sp = {};
      }
      $ionicNativeTransitions.stateGo($stateParams.backUrl, sp, {
        "type": "slide",
        "direction": "right",
        "duration": 500
      });
    };

  })


  /**
   * 健康盒子消息详情页面
   */
  .controller('MsgDetailCtrl', function ($stateParams, $scope, $rootScope, $ionicNativeTransitions, $cacheFactory, $state, $timeout) {
    var cache = $cacheFactory.get($state.current.name);
    if (!cache) {
      cache = $cacheFactory($state.current.name);
    }
    cache.put('stateParams', $stateParams);


    $scope.msg = {
      id: $stateParams.id,
      title: $stateParams.title,
      content: $stateParams.content,
      time: parseInt($stateParams.time),
      receive: $stateParams.sendTo
    }


    /**
     * 返回
     */
    $scope.goBack = function () {
      var param = $cacheFactory.get($stateParams.backUrl);
      var sp = null;
      if (param) {
        sp = param.get('stateParams');
        if (!sp) {
          sp = {};
        }
      } else {
        sp = {};
      }
      $ionicNativeTransitions.stateGo($stateParams.backUrl, sp, {
        "type": "slide",
        "direction": "right",
        "duration": 500
      });
    };

  })

  /**
   * 健康盒子用户页面
   */
  .controller('BoxUserCtrl', function ($stateParams, $scope, $rootScope, $ionicNativeTransitions, $cacheFactory, $state, $timeout) {
    var cache = $cacheFactory.get($state.current.name);
    if (!cache) {
      cache = $cacheFactory($state.current.name);
    }
    cache.put('stateParams', $stateParams);
    var prePageCache = $cacheFactory.get($stateParams.backUrl);
    $scope.form = {
      users: prePageCache.get($scope.user.userId + "_boxUser"),
      title: $stateParams.boxName
    }


    // /**
    //  * 跳转到发送消息页面
    //  */
    // $scope.sendMsg=function () {
    //   $ionicNativeTransitions.stateGo('g_box_news', {backUrl: $state.current.name}, {
    //     "type": "slide",
    //     "direction": "left",
    //     "duration": 500
    //   });
    // }

    /**
     * 查看用户硬件检测的健康数据
     * @param userId
     */
    $scope.scanHealthData = function (userId) {
      $ionicNativeTransitions.stateGo('g_health_data', {backUrl: $state.current.name, userId: userId}, {
        "type": "slide",
        "direction": "left",
        "duration": 500
      });
    }


    /**
     * 返回
     */
    $scope.goBack = function () {
      var param = $cacheFactory.get($stateParams.backUrl);
      var sp = null;
      if (param) {
        sp = param.get('stateParams');
        if (!sp) {
          sp = {};
        }
      } else {
        sp = {};
      }
      $ionicNativeTransitions.stateGo($stateParams.backUrl, sp, {
        "type": "slide",
        "direction": "right",
        "duration": 500
      });
    };

  })

  /**
   * 健康盒子消息编辑页面
   */
  .controller('BoxMsgEditCtrl', function ($stateParams, $scope, $rootScope, $ionicNativeTransitions, $cacheFactory, $state, $timeout, DeviceData) {
    var cache = $cacheFactory.get($state.current.name);
    if (!cache) {
      cache = $cacheFactory($state.current.name);
    }
    cache.put('stateParams', $stateParams);

    console.debug("deviceId:", $stateParams.deviceId);

    var userCache = $cacheFactory.get('g_box_news');
    $scope.form = {
      users: userCache.get($scope.user.userId + "_boxUser"),
      content: "",
      sendTo: 0
    }

    if ($scope.form.users) {
      $scope.form.users.forEach(function (item, index) {
        if (item.isCurrent) {
          $scope.form.sendTo = item.id;
        }
      });
    }

    $scope.selectOne = function (id, user) {
      $(".g_box_img").removeClass("g_radio_chose");
      $("#" + id).addClass("g_radio_chose");
      // console.debug("userId:", user.id);
      $scope.form.sendTo = user.id;
    }

    // function selectOne(obj) {
    //   $(".g_box_img").removeClass("g_radio_chose");
    //   $(obj).addClass("g_radio_chose");
    //     console.debug("userId:", user.id);
    //     $scope.form.sendTo = user.id;
    // }


    $scope.send = function () {
      DeviceData.sendMsg($scope.form.content, $scope.form.sendTo, $rootScope.user.userId, $stateParams.deviceId).then(function (data) {
        console.debug("arg:", data.msg);
        $scope.$emit("SendMsg", data.msg);
        $scope.goBack();
      }, function (e) {
        console.error(e);
      });
    }


    /**
     * 返回
     */
    $scope.goBack = function () {
      var param = $cacheFactory.get($stateParams.backUrl);
      var sp = null;
      if (param) {
        sp = param.get('stateParams');
        if (!sp) {
          sp = {};
        }
      } else {
        sp = {};
      }
      $ionicNativeTransitions.stateGo($stateParams.backUrl, sp, {
        "type": "slide",
        "direction": "right",
        "duration": 500
      });
    };

  })


  /**
   * 健康盒子硬件测试数据页
   */
  .controller('HealthDataCtrl', function ($stateParams, $scope, $rootScope, $ionicNativeTransitions, $cacheFactory, $state, $timeout, DeviceData, $ionicLoading) {
    var cache = $cacheFactory.get($state.current.name);
    if (!cache) {
      cache = $cacheFactory($state.current.name);
    }
    cache.put('stateParams', $stateParams);

    var idsCache = $cacheFactory.get("g_box_news");
    var ids = idsCache.get($scope.user.userId + "_boxUserIds");   //token数组
    var userId = $stateParams.userId;
    var token = ids[userId];
    var page = 1;
    //TODO log
    console.debug("token:", token);
    $scope.innerList = [];
    $scope.hasMore = true;
    var haveData = true;

    $ionicLoading.show();
    $scope.queryByPage = function (page) {
      DeviceData.queryHealthInfo(token, page).then(function (d) {
        console.info("d.data:", d.data);
        if (!(d.data) || d.data.length == 0) {
          haveData = false;
        }
        $scope.innerList = $scope.innerList.concat(d.data);
        console.debug("$scope.innerList:", $scope.innerList);

        $scope.$broadcast('scroll.infiniteScrollComplete');
        $ionicLoading.hide();
      }, function (e) {
        ErrorShow("网络异常，请返回重新进入页面");
        $ionicLoading.hide();
        $scope.$broadcast('scroll.infiniteScrollComplete');
        console.error(e);
      });
    }

    $scope.queryByPage(page);

    $scope.loadMore = function () {
      if (!haveData) {
        ErrorShow("已经到底了");
        $scope.hasMore = false;
      }

      page++;
      console.debug("arg:", "加载中");
      $scope.queryByPage(page);

    }

    /**
     * 返回
     */
    $scope.goBack = function () {
      var param = $cacheFactory.get($stateParams.backUrl);
      var sp = null;
      if (param) {
        sp = param.get('stateParams');
        if (!sp) {
          sp = {};
        }
      } else {
        sp = {};
      }
      $ionicNativeTransitions.stateGo($stateParams.backUrl, sp, {
        "type": "slide",
        "direction": "right",
        "duration": 500
      });
    };

  })







