/**
 * 聊天信息类
 * @param userId
 * @param serviceId
 * @param type
 * @param content
 * @param fileId
 * @param serviceName
 * @param noReadCount
 * @constructor
 */
function Chat(userId, serviceId, type, content, fileId, serviceName, noReadCount, sendTime) {
    this.userId = userId;
    this.serviceId = serviceId;
    this.type = type;
    this.content = content;
    this.fileId = fileId;
    this.serviceName = serviceName;
    this.noReadCount = noReadCount;
    this.sendTime = sendTime;

}

/**
 * Created by liushangqing on 2016/7/5.
 */
/**
 *与医生端相关业务
 */
angular.module('Doctor', [])
    .factory('DoctorService', function ($http, $q, $rootScope, $cordovaBarcodeScanner, drugService, $cordovaToast, $cacheFactory, WebSql) {
        return {
            //扫描二维码
            scanQrcode: function () {
                var q = $q.defer();
                $cordovaBarcodeScanner
                    .scan()
                    .then(function (barcodeData) {
                        console.log('扫描结果', JSON.stringify(barcodeData));
                        if (!barcodeData.cancelled) {
                            drugService.createRelation(barcodeData.text).then(function (d) {
                                console.log('创建关系结果：', d);
                                q.resolve(d);
                                if (d.status) {
                                    $cordovaToast.showShortBottom('成功添加医生');
                                    WebSql.insertChatMessage($rootScope.user.userId, d.doctorId, d.name, "text", "您好，我有问题想要咨询您", d.headImg, null, 1, 1, null, new Date().getTime());
                                } else {
                                    $cordovaToast.showShortBottom(d.message);
                                }
                            }, function (e) {
                                console.log(e);
                                q.reject('网络异常');
                            });
                        }

                    }, function (error) {
                        console.log(error);
                    });
                return q.promise;
            },
            //根据医生姓名、医院、科室、专长查询医生列表
            searchDoctors: function (keyword) {
                var q = $q.defer()
                var req = {
                    method: 'post',
                    url: $rootScope.reqUrl + "/find/doctor.htm",
                    params: {
                        token: $rootScope.token,
                        keyword: keyword
                    },
                    timeout: 3000
                };
                $http(req).success(function (result) {
                    if (result.status) {
                        q.resolve(result);
                    } else {
                        q.reject(result);
                    }
                }).error(function (result) {
                    q.reject("网络异常");
                });
                return q.promise;
            },

            /**
             * 获取医生资料
             * @param doctorId
             * @returns {*}
             */
            getDoctorInfo: function (doctorId) {
                var q = $q.defer();
                var req = {
                    method: 'GET',
                    url: $rootScope.reqUrl + "/doctor/profile.htm",
                    params: {
                        doctorId: doctorId
                    },
                    timeout: 4000
                };
                $http(req).success(function (result) {
                    q.resolve(result);
                }).error(function (e) {
                    q.reject(e);
                });
                return q.promise;
            },
            /**
             * 查询所有医生列表
             * @returns {*}
             */
            getAllDoctors: function () {
                var q = $q.defer();
                var req = {
                    method: 'GET',
                    url: $rootScope.reqUrl + "/doctors/list.htm",
                    params: {
                        token: $rootScope.token
                    },
                    timeout: 5000
                };
                $http(req).success(function (result) {
                    console.log(result);
                    q.resolve(result.data);
                }).error(function (e) {
                    q.reject(e);
                });
                return q.promise;
            },
            /**
             * 从缓存获取医生信息
             * @param doctorId
             * @returns {null}
             */
            getDoctorFromCache: function (doctorId) {
                var doctor = {};
                var doctors_cache = $cacheFactory.get("doctors_cache");
                if (!doctors_cache) {
                    return doctor;
                }
                var doctorList = doctors_cache.get("doctorList");
//                console.log('doctorList:',doctorList);
                if (doctorList.length > 0) {
                    for (var i = 0; i < doctorList.length; i++) {
                        if (doctorList[i].id == doctorId) {
                            doctor = doctorList[i];
                            break;
                        }
                    }
                }
                return doctor;
            }//此方法结束
        }
    })

    //咨询页面
    .controller('consultCtrl', function ($stateParams, $scope, $rootScope, $ionicNativeTransitions, $cacheFactory, $state, WebSql, BadgeService, DoctorService) {
        //页面跳转参数存储
        var cache = $cacheFactory.get($state.current.name);
        if (!cache) {
            cache = $cacheFactory($state.current.name);
        }
        cache.put('stateParams', $stateParams);
        cache.put('special_back', true);
        $scope.form={
          notify: false,
          is_renew: false,  //是否显示续费标标识
          endTime: $rootScope.user.ymEndTime
        }
//        if (localStorage.getItem("isAddDoctorNotifyShow")!= 1||!localStorage.getItem("isAddDoctorNotifyShow")) {
//            $scope.form.notify=true;
//            localStorage.setItem("isAddDoctorNotifyShow", 1);
//        }

        $scope.hideNotify=function(){
            $scope.form.notify=false;
        }

        /**
         * 显示最近聊天列表
         */
        $scope.showList = function () {
            var totalBadge = 0;
            WebSql.selectChatList($rootScope.user.userId).then(function (data) {
                var list = [];
                console.log(data);
                for (var i in data) {
                    var noReadCount = BadgeService.getBadgeCount(parseInt(data[i].serviceId));
                    if (!isNaN(noReadCount)) {
                        totalBadge += noReadCount;
                    }
                    //如果不存在角标
                    if (!noReadCount) {
                        noReadCount = "";
                    }
                    if (data[i].fileId == 'undefined' || !data[i].fileId) {
                        data[i].fileId = "";
                    }

                    if (data[i].type == 'image') {
                        data[i].content = "[图片]";
                    } else if (data[i].type == 'audio') {
                        data[i].content = "[语音]";
                    }
                    var chat = new Chat(data[i].userId, data[i].serviceId, data[i].type,
                        data[i].content, data[i].fileId, data[i].serviceName, noReadCount, data[i].sendTime);
                    list.push(chat);
                }
                $rootScope.badgeCount = totalBadge;
                console.log("未读消息总数：", totalBadge);
//                console.log("list:", list);
                $scope.list = list;
            }, function (e) {
                console.log(e);
            });
        }

        $scope.showList();

        /**
         *跳到添加医生界面
         */
        $scope.addDoctor = function () {
            if ($rootScope.userType) {
                if ($rootScope.userType == 6) {
                    ErrorShow("在我页面绑定手机号后方可咨询");
                    return false;
                }
            }
            console.log("22");
            $ionicNativeTransitions.stateGo('add_doctor', {backUrl: 'doctor_consult'}, {
                "type": "slide",
                "direction": "left",
                "duration": 500
            });
        }

        /**
         * 跳到黄药师页面
         */
        var doctorCache = $cacheFactory.get("doctorCache");
        if (!doctorCache) {
            doctorCache = $cacheFactory("doctorCache");
        }
        $scope.zjDoctor = function (name, id) {
            id = parseInt(id);
            console.log("name:" + name + "\n" + "id：" + id);
//            DoctorService.getDoctorInfo(id).then(function (data) {
//                console.log("医生资料：", data);
//                doctorCache.put(id + "", data);
//                doctorCache.put('headImg',data.headImg);
//            }, function (e) {
//                console.log(e);
//            });
            $ionicNativeTransitions.stateGo('z_message_chat', {backUrl: 'doctor_consult', doctorName: name, doctorId: id}, {
                "type": "slide",
                "direction": "left",
                "duration": 500
            });
        }

        /**
         * 收到消息时刷新聊天列表
         */

        $scope.$on("receiveMsg", function (event, data) {
            $scope.showList();
        });

        var c_name = $state.current.name;
        $scope.$on(c_name + '_HARDWARE_BACK', function () {
            $scope.goBack();
        });


      if ($rootScope.user.ymDaysLeft <= 30) {
        console.info($rootScope.user.ymDaysLeft);
        $scope.form.is_renew = true;
        $("#consult_id").css({"margin-top": "26px"});
      }

      /**
       *远盟续费（去往付费页面）
       */
      $scope.renew = function () {
        $ionicNativeTransitions.stateGo('g_pay', {backUrl: 'doctor_consult'}, {
          "type": "slide",
          "direction": "left",
          "duration": 500
        });
      }

        /**
         * 返回
         */
        $scope.goBack = function () {
            console.log("回退");
            //取出回退页面跳转参数
            var param = $cacheFactory.get("doctor_consult");
            var sp = null;
            //如果不在页面参数则设置为空串
            if (param) {
                sp = param.get('stateParams');
                console.log("sp:", sp);
                if (!sp) {
                    sp = {};
                }
            } else {
                sp = {};
            }
            $ionicNativeTransitions.stateGo(sp.backUrl, sp, {
                "type": "slide",
                "direction": "right",
                "duration": 500
            });
        };

    })

    //添加医生页面
    .controller('addDoctorCtrl', function ($stateParams, $scope, $rootScope, $ionicNativeTransitions, $cacheFactory, $state, DoctorService, $window, $location, $ionicScrollDelegate, $cordovaBarcodeScanner, drugService, $cordovaToast) {
        //页面跳转参数存储
        var cache = $cacheFactory.get($state.current.name);
        if (!cache) {
            cache = $cacheFactory($state.current.name);
        }
        cache.put('stateParams', $stateParams);

        /**
         * 获取所有医生
         *
         */
        var doctors_cache = $cacheFactory.get("doctors_cache");
        if (!doctors_cache) {
            doctors_cache = $cacheFactory("doctors_cache");
        }
        if (!doctors_cache.get('doctorList')) {
            DoctorService.getAllDoctors().then(function (data) {
                console.log(data);
                $scope.items = dealArray(data);
                doctors_cache.put('doctorList', $scope.items);
                var k = [];
                angular.forEach(Object.keys($scope.items), function (value, key) {
                    k.push(value);
                });
                //排序
                $scope.keys = k.sort(function (a, b) {
                    if (a < b) {
                        return -1;
                    }
                    if (a == b) {
                        return 0;
                    }
                    else {
                        return 1;
                    }
                });


            }, function (e) {
                console.log(e);
            });
        } else {
            $scope.items = doctors_cache.get('doctorList');
        }


        /**
         *跳到与医生聊天的界面
         */
        $scope.askDoctor = function (id, name) {
            console.log('医生id:' + id + " 姓名：" + name);
            $ionicNativeTransitions.stateGo('z_message_chat', {backUrl: 'add_doctor', doctorId: id, doctorName: name}, {
                "type": "slide",
                "direction": "left",
                "duration": 500
            });
        }

        /**
         * 点击字母显示对应的患者
         * @param c
         */
        $scope.show = function (c) {
            var id = "index_" + c;
            var obj = $window.document.getElementById("index_" + c);
            if (obj) {
                $location.hash(id);
                $ionicScrollDelegate.anchorScroll();
            }
        };


        /**
         * 扫描二维码添加医生
         */
        $scope.scan = function () {
            DoctorService.scanQrcode().then(function () {
                console.log("data");
            }, function (e) {
                ErrorShow(e);
            });
        }

//        /**
//         * 搜素医生根据姓名、科室、医院、专长、
//         */
//        $scope.findDoctor = function () {
//            DoctorService.searchDoctors($scope.form.keyword).then(function (d) {
//                console.log(d);
//                $scope.list = d.data;
//            }, function (e) {
//                console.log(e);
//            });
//        }

        /**
         * 返回
         */
        $scope.goBack = function () {
            console.log("回退");
            //取出回退页面跳转参数
            var param = $cacheFactory.get($stateParams.backUrl);
            var sp = null;
            //如果不在页面参数则设置为空串
            if (param) {
                sp = param.get('stateParams');
                if (!sp) {
                    sp = {};
                }
            } else {
                sp = {};
            }
            $ionicNativeTransitions.stateGo($stateParams.backUrl, sp, {
                "type": "slide",
                "direction": "right",
                "duration": 500
            });
        };

    })

    //医生个人信息页面
    .controller('DoctorDataCtrl', function ($stateParams, $scope, $rootScope, $ionicNativeTransitions, $cacheFactory, $state, DoctorService, $timeout) {
        //页面跳转参数存储
        var cache = $cacheFactory.get($state.current.name);
        if (!cache) {
            cache = $cacheFactory($state.current.name);
        }
        cache.put('stateParams', $stateParams);

        /**
         * 获取医生详细资料
         */
        $scope.doctor = {};
        var doctorInfoCache = $cacheFactory.get("doctorInfoCache");
        var doctorId = $stateParams.doctorId;
        if (doctorId) {
            $scope.doctor = doctorInfoCache.get(doctorId);
        } else {
            console.log("上个页面没有传doctorId过来");
        }

        /**
         * 返回
         */
        $scope.goBack = function () {
            console.log("回退");
            //取出回退页面跳转参数
            var param = $cacheFactory.get($stateParams.backUrl);
            var sp = null;
            //如果不在页面参数则设置为空串
            if (param) {
                sp = param.get('stateParams');
                if (!sp) {
                    sp = {};
                }
            } else {
                sp = {};
            }
            $ionicNativeTransitions.stateGo($stateParams.backUrl, sp, {
                "type": "slide",
                "direction": "right",
                "duration": 500
            });
        };

    });

