angular.module('OnLineCustomer', [])

    .factory('onlineService', function ($http, $q, $rootScope) {
        // Might use a resource here that returns a JSON array
        return {
            getChatInfo: function () {
                var q = $q.defer();
                var req = {
                    method: 'GET',
                    url: $rootScope.reqUrl + "/patient/im/getService.htm",
                    params: {
                        token: $rootScope.token
                    },
                    timeout: 5000
                };
                $http(req).success(function (result) {
                    //console.log("查询结果->" + JSON.stringify(result));
                    if (result.status) {
                        q.resolve(result);
                    } else {
                        q.reject(result);
                    }
                }).error(function (result) {
                    q.reject("网络异常");
                });
                return q.promise;
            },
            getDoctorImId: function (doctorId) {
                var q = $q.defer();
                var req = {
                    method: 'GET',
                    url: $rootScope.reqUrl + "/patient/im/getDoctorInfo.htm",
                    params: {
                        doctorId: doctorId
                    },
                    timeout: 5000
                };
                $http(req).success(function (result) {
                    q.resolve(result);
                }).error(function (e) {
                    q.reject(e);
                });
                return q.promise;
            }

        };
    })
/**
 * 角标数量控制
 */
    .service('BadgeService', function ($rootScope, $cacheFactory, WebSql, DoctorService, $location) {
        var badgeCache = $cacheFactory('badgeCache');
        return{
            /**
             * 保存并返回角标数量
             * @param doctorId
             * @returns {*}
             */
            saveBadgeCount: function (doctorId) {
                doctorId = parseInt(doctorId);   //转化为整形
                var preCount = badgeCache.get(doctorId);
                console.log("preCount:" + preCount);
                if (!preCount) {
                    badgeCache.put(doctorId, 1);
                } else {
                    preCount++;
                    badgeCache.put(doctorId, preCount);
                }
                return badgeCache.get(doctorId);
            },
            /**
             * 返回对应医生的未读消息数量
             * @param doctorId
             * @returns {*}
             */
            getBadgeCount: function (doctorId) {
                return badgeCache.get(doctorId);
            },
            /**
             * 将对应医生的未读消息置为0
             * @param doctorId
             */
            clearBadge: function (doctorId) {
                badgeCache.put(doctorId, "");
            },
            //得到医生信息
            getDoctorProfile: function (doctorId) {
                var doctor = {};
                var doctors_cache = $cacheFactory.get("doctors_cache");
                if (doctors_cache) {
                    var doctor_list = doctors_cache.get("doctorList");
                    console.log("缓存的doctor_list:", doctor_list);
                    for (var i in doctor_list) {
                        if (doctor_list[i].id == doctorId) {
                            doctor = doctor_list[i];
                        }
                    }
//                } else {
//                    DoctorService.getDoctorInfo(doctorId).then(function (data) {
//                        console.log('请求网络',data);
//                       doctor.id=data.profile.id;
//                       doctor.name=data.profile.name;
//                       doctor.headImg=data.headImg;
//                        q.resolve(doctor);
//                    }, function (e) {
//                        q.reject('网络延时');
//                        ErrorShow("网络异常");
//                    });
                }
                return doctor;
            }
        }
    })

    .controller('onlineController', function ($scope, imageUtil, fileUtil, $rootScope, $ionicNativeTransitions, $cacheFactory, $state, $stateParams, $ionicScrollDelegate, $cordovaMedia, $sce, $timeout, $ionicGesture, WebSql, onlineService, $interval, BadgeService, DoctorService, $location) {
        //页面跳转参数存储
        console.log($stateParams);
        var cache = $cacheFactory.get($state.current.name);
        if (!cache) {
            cache = $cacheFactory($state.current.name);
        }
        cache.put('special_back', true);
        cache.put('stateParams', $stateParams);
        /**
         * 存储当前页面的医生参数
         * @type {Object}
         */
        var param_cache = $cacheFactory.get("param_cache");
        if (!param_cache) {
            param_cache = $cacheFactory("param_cache");
        }


        $scope.showTimeFlag = false;
        var textFlag = false;
        var flag = false;
        var sendFlag = true;
        var conn = $rootScope.connection; //环信连接
        console.log("conn:", conn);
        $scope.form = {
            send_content: null,
            load: false
        };
        $scope.user = {
            userName: null,
            password: null,
            serviceId: null,
            serviceName: null
        };
        var extraSend = { //发消息需要携带的内容
            fromId: $rootScope.user.userId,
            fromName: $rootScope.user.name,
            fromHeadImg: $rootScope.user.headImg
        }

        if ($stateParams.doctorName) {
            $scope.title = $stateParams.doctorName;
            param_cache.put("doctorName", $scope.title);
        } else {
            $scope.title = param_cache.get("doctorName");
        }
        onlineService.getChatInfo().then(function (data) {
            console.log(data);
            $scope.user.userName = data.imid;
            $scope.user.password = data.passwd;
            //若传过来doctorId则跟医生聊天
            $scope.doctorId = "";
//            $scope.user.serviceId=data.servicer;
            if ($stateParams.doctorId) {
                //获取医生信息
                $scope.doctorId = $stateParams.doctorId;
                param_cache.put("doctorId", $scope.doctorId);

            } else {
                $scope.doctorId = param_cache.get("doctorId");
                console.log("上个页面传过来的doctorId:", $scope.doctorId);
            }

            $scope.doctor = {};
            //设置医生信息缓存
            var doctorInfoCache = $cacheFactory.get("doctorInfoCache");
            if (!doctorInfoCache) {
                doctorInfoCache = $cacheFactory("doctorInfoCache");
            }
            DoctorService.getDoctorInfo($scope.doctorId).then(function (data) {
                console.log('后台查询医生资料', data);
                $scope.doctor.headImg = data.headImg;
                $scope.user.serviceId = data.mapping.id;
                $scope.user.name = data.profile.name;
                //更新前端数据库医生信息
                console.log("data.profile.name:" + data.profile.name + "data.headImg:" + data.headImg + "doctorId:" + $scope.doctorId);
                WebSql.updateDoctorInfo(data.profile.name, data.headImg, $scope.doctorId).then(function (data) {
                    console.log(data);
                }, function (e) {
                    console.log(e);
                });
                doctorInfoCache.put($scope.doctorId, data);
            }, function (e) {
                console.log(e);
            });
            var badgeNum = BadgeService.getBadgeCount($scope.doctorId);
            console.log('badgeNum:', badgeNum);
            if (badgeNum && !isNaN(badgeNum)) {
                $rootScope.badgeCount -= badgeNum;
                console.log('badgeNum:', badgeNum);
                console.log("$rootScope.badgeCount:", $rootScope.badgeCount);
            }
            //清空当前角标
            BadgeService.clearBadge($scope.doctorId);
            $scope.showTimeFlag = true;  //打开新连接
//            conn.open({
//                user: $scope.user.userName,
//                pwd: $scope.user.password,
////                appKey: 'sinoicity-health#doctorapp'
//                appKey: 'sinoicity-health#zhylapp'
//            });
        }, function (error) {
        });
        $scope.messageDetils = [];
        /**
         * 处理收到的信息
         * @param message
         */
        $scope.$on('receiveMsg', function (event, data) {
//            $scope.form.send_content = null;
            console.log('接受到消息的广播', data);
//            data.content=$sce.trustAsResourceUrl(data.content);
            if ($scope.doctorId == data.fromId) {
                $scope.messageDetils.push(data);
            }
//            $scope.$apply();
            $ionicScrollDelegate.scrollBottom(true);
        });

        var timeTemp = null;
        $scope.sendTextMsg = function () {
            textFlag = true;
            if (!$scope.form.send_content) {
                $scope.imageButton();
                return;
            }
            conn.sendTextMessage({
                to: $scope.user.serviceId,
                msg: $scope.form.send_content,
                ext: extraSend
            });
            var msgObj = new Object();
            msgObj.content = $scope.form.send_content;
            msgObj.isFromeMe = true;
            msgObj.type = "text";
            if ($scope.messageDetils.length > 0) {
                console.log("发送时间和最后一条消息相差时间", new Date().getTime() - $scope.messageDetils[$scope.messageDetils.length - 1].time);
                //判断最后一条消息的时间和当前时间相差时间
                if (Math.abs(new Date().getTime() - $scope.messageDetils[$scope.messageDetils.length - 1].time) > 10 * 60 * 1000) {
                    msgObj.showTimeFlag = true;
                } else {
                    msgObj.showTimeFlag = false;
                }
            } else {
                msgObj.showTimeFlag = true;
            }
            msgObj.sendTime = formatDate(new Date());
            $scope.messageDetils.push(msgObj);
            console.log('头像', $scope.doctor.headImg);
            WebSql.insertChatMessage($rootScope.user.userId, $scope.doctorId, $scope.title, msgObj.type, $scope.form.send_content, $scope.doctor.headImg, null, 1, 1, null, new Date().getTime());
            console.log('$scope.messageDetils:' + $scope.messageDetils);
            $scope.form.send_content = null;
            $ionicScrollDelegate.scrollBottom(true);
            $timeout(function () {
                $("#inMsg").focus();
            }, 10);
            /*            $timeout(function () {
             // $ionicScrollDelegate.scrollBottom(true);
             //$rootScope.bug.clear();
             $ionicScrollDelegate.scrollBy(0, $rootScope.screenHeight);
             $("#inMsg").focus();
             }, 200);*/
        };
        $scope.sendFileMsg = function (type, extras) {
            textFlag = false;
            conn.sendTextMessage({
                to: $scope.user.serviceId,
                msg: type,
                ext: extras
            });
            if (type == "audio") {
                WebSql.insertChatMessage($rootScope.user.userId, $scope.doctorId, $scope.title, type, extras.url, $scope.doctor.headImg, extras.audioTime, 1, 1, null, new Date().getTime());
            } else {
                WebSql.insertChatMessage($rootScope.user.userId, $scope.doctorId, $scope.title, type, extras.url, $scope.doctor.headImg, null, 1, 1, null, new Date().getTime());
            }

        };
        $scope.selectImageByPic = function () {
            imageUtil.imagePick($rootScope.screenWidth, $rootScope.screenHeight).then(function (data) {
                if (!data) {
                    return;
                }
                var msgObj = new Object();
                msgObj.content = data;
                msgObj.isFromeMe = true;
                msgObj.type = "image";
                if ($scope.messageDetils.length > 0) {
                    console.log("$scope.messageDetils[$scope.messageDetils.length - 1].time:", $scope.messageDetils[$scope.messageDetils.length - 1].time);
                    console.log(new Date().getTime() - $scope.messageDetils[$scope.messageDetils.length - 1].time);
                    //判断最后一条消息的时间和当前时间相差时间
                    if (Math.abs(new Date().getTime() - $scope.messageDetils[$scope.messageDetils.length - 1].time) > 10 * 60 * 1000) {
                        msgObj.showTimeFlag = true;
                    } else {
                        msgObj.showTimeFlag = false;
                    }
                } else {
                    msgObj.showTimeFlag = true;
                }
                msgObj.sendTime = formatDate(new Date());
                $scope.messageDetils.push(msgObj);
                var index = $scope.messageDetils.length - 1;
                $timeout(function () {
                    $("#zz_img_1_" + index).css("display", "block");
                    $("#zz_img_2_" + index).css("display", "block");
                }, 100);
                $scope.form.send_content = null;
                $(".z_chat").css("height", "54px");
                $(".z_chatList  .scroll").css("padding-bottom", '0');
                flag = false;
                $ionicScrollDelegate.scrollBottom(true);
                /*                $timeout(function () {
                 $ionicScrollDelegate.scrollBottom(true);
                 //$ionicScrollDelegate.scrollBy(0, $rootScope.screenHeight);
                 }, 150);*/

                imageUtil.uploadImages(data, "/message/image/uploadImg.htm", $rootScope.token).then(function (ret) {
                    if (ret.status == 1) {
                        var extras = {type: 'image', url: ret.url, fileId: ret.fileId, userId: $rootScope.user.userId};
//                        $("#zz_img_1_" + index).css("display", "none");
//                        $("#zz_img_2_" + index).css("display", "none");
                        $("#zz_img_1_" + index).hide();
                        $("#zz_img_2_" + index).hide();
                        $scope.sendFileMsg('image', extras);
                    }
                }, function (error) {
                })
            }, function (err) {
            });
        };
        $scope.selectImageByCamera = function () {
            imageUtil.takePhoto($rootScope.screenWidth, $rootScope.screenHeight, Camera.DestinationType.FILE_URI).then(function (data) {
                if (!data) {
                    return;
                }
                var msgObj = new Object();
                msgObj.content = data;
                msgObj.isFromeMe = true;
                msgObj.type = "image";
                if ($scope.messageDetils.length > 0) {
                    console.log(new Date().getTime() - $scope.messageDetils[$scope.messageDetils.length - 1].time);
                    //判断最后一条消息的时间和当前时间相差时间
                    if (Math.abs(new Date().getTime() - $scope.messageDetils[$scope.messageDetils.length - 1].time) > 10 * 60 * 1000) {
                        msgObj.showTimeFlag = true;
                    } else {
                        msgObj.showTimeFlag = false;
                    }
                } else {
                    msgObj.showTimeFlag = true;
                }
                msgObj.sendTime = formatDate(new Date());
                $scope.messageDetils.push(msgObj);
                var index = $scope.messageDetils.length - 1;
                $timeout(function () {
                    $("#zz_img_1_" + index).css("display", "block");
                    $("#zz_img_2_" + index).css("display", "block");
                }, 100);
                $scope.form.send_content = null;
                $(".z_chat").css("height", "54px");
                $(".z_chatList  .scroll").css("padding-bottom", '0');
                flag = false;
                $ionicScrollDelegate.scrollBottom(true);
                /*                $timeout(function () {
                 // $ionicScrollDelegate.scrollBottom(true);
                 $ionicScrollDelegate.scrollBy(0, $rootScope.screenHeight);
                 }, 200);*/

                imageUtil.uploadImages(data, "/message/image/uploadImg.htm", $rootScope.token).then(function (ret) {
                    if (ret.status == 1) {
                        var extras = {type: 'image', url: ret.url};
                        $("#zz_img_1_" + index).css("display", "none");
                        $("#zz_img_2_" + index).css("display", "none");
                        $scope.sendFileMsg('image', extras);
                    }
                }, function (error) {
                })
            }, function (err) {
            });
        };
        $scope.form = {
            buttonFlag: true,
            textFlag: true
        };

        var heightFlag = true;
        $scope.showButton = function () {
            $("input").blue;
            if (flag) {
                $(".z_chat").css("height", "54px");
                $(".z_chatList  .scroll").css("padding-bottom", '0');
                flag = false;
            } else {
                if ($scope.form.buttonFlag) {
                    $scope.form.buttonFlag = false;
                    $scope.form.textFlag = false;
                    $("#clickRecord").css("display", "block");
                    $("#releaseRecord").css("display", "none");
                    return;
                }
                if (!$scope.form.buttonFlag) {
                    $scope.form.buttonFlag = true;
                    $scope.form.textFlag = true;
                }
            }
            $ionicScrollDelegate.scrollTop(true);
            $ionicScrollDelegate.scrollBottom(true);
            $("input").blue;
        };
        //获取窗口的高度
        var clientY = document.documentElement.clientHeight;
        /**
         * 设置定时器不断判断输入法是否弹出
         */
        $scope.listenKeyBord = $interval(function () {
            if ($(':focus').length > 0 && heightFlag) {
                $(".z_chat").css("height", "54px");
                $(".z_chatList  .scroll").css("padding-bottom", '0');
                $ionicScrollDelegate.scrollTop(true);
                $ionicScrollDelegate.scrollBottom(true);
                flag = false;
                heightFlag = false;
                return;
            }
            if (document.documentElement.clientHeight < clientY && $(':focus').length > 0) {
                $ionicScrollDelegate.scrollBottom(true);
                //$("#inMsg").focus();
                textFlag = true;
                return;
                /*                $timeout(function () {
                 //$ionicScrollDelegate.scrollBottom(true);
                 $ionicScrollDelegate.scrollBy(0, $rootScope.screenHeight);
                 $("#inMsg").focus();
                 }, 300);*/
                // $ionicScrollDelegate.scrollBottom(true);
            }
            if (document.documentElement.clientHeight == clientY && textFlag) {
                //   $(".z_chatList  .scroll").css("padding-bottom", '');
                $ionicScrollDelegate.scrollTop(true);
                $ionicScrollDelegate.scrollBottom(true);
                textFlag = false;
            }
        }, 250);

        /**
         * 点击空白部分隐藏底部图片选择项
         */
        $scope.hideFoot = function () {
            $(".z_chat").css("height", "54px");
            $(".z_chatList  .scroll").css("padding-bottom", '0');
            flag = false;
            console.log(flag);
        };
        /**
         * 点击键盘按钮显示输入框
         * 点击语音显示语音输入框
         */
        $scope.imageButton = function () {
            $("input").blur();
            if (!flag) {
                $(".z_chat").css("height", "170px");
                $(".z_chatList  .scroll").css("padding-bottom", '117px');
                heightFlag = true;
            } else {
                $(".z_chat").css("height", "54px");
                $(".z_chatList  .scroll").css("padding-bottom", '0');
            }
            $ionicScrollDelegate.scrollTop(true);
            $ionicScrollDelegate.scrollBottom(true);
            /*            $timeout(function () {
             $ionicScrollDelegate.scrollBottom(true);
             $rootScope.bug.clear();
             }, 1);*/
            flag = !flag;
        };
        var sendFlag = true;
        $ionicGesture.on('touchmove', function (e) {
            if (e.changedTouches[0].clientY < 450) {
                sendFlag = false;
                $("#zz_cancel").css("display", "block");
                $("#zz_show_voice").css("display", "none");
            } else {
                sendFlag = true;
                $("#zz_cancel").css("display", "none");
                $("#zz_show_voice").css("display", "block");
            }
        }, angular.element(document.getElementById('clickRecord')));

        var media = null;       //媒体对象
        var audioSrc = null;    //录音文件路径
        var startTime = null;   //开始时间
        /**
         * 开始录音
         */
        $scope.startRecord = function () {
            $("#zz_msg_voice").css("display", "block");
            $("#zz_cancel").css("display", "none");
            $("#zz_exit").css("display", "block");
            $("#zz_show_voice").css("display", "block");
            $("#inMsg").css("display", "none");
            $("#clickRecord").css("display", "none");
            $("#releaseRecord").css("display", "block");
            //开始监听录音的声音的分贝
            //change_db();
            var mediaName = new Date().getTime() + '.amr';
            audioSrc = window.devicePath + 'HealthPatient/audio/' + mediaName;
            media = $cordovaMedia.newMedia(audioSrc);
            media.startRecord();
            startTime = new Date().getTime();
        };
        /**
         * 停止录音
         */
        var tempTime = null;
        $scope.stopRecord = function () {
            //停止监听声音的分贝
            //stop_db();
            $("#zz_msg_voice").css("display", "none");
            $("#inMsg").css("display", "none");
            $("#releaseRecord").css("display", "none");
            $("#clickRecord").css("display", "block");
            media.stopRecord();
            media.release();
            if (sendFlag) {
                var audioTime = new Date().getTime() - startTime;
                //当录音文件小于一秒时不发送录音文件
                if (audioTime < 1000) {
                    return;
                }
                audioTime = Math.floor(audioTime / 1000);
                tempTime = audioTime;
                audioTime = changeTimeType(audioTime);
                var msgObj = new Object();
                //msgObj.content = $sce.trustAsResourceUrl(audioSrc);
                msgObj.content = audioSrc;
                msgObj.isFromeMe = true;
                msgObj.audioTime = audioTime;
                msgObj.tempTime = tempTime;
                msgObj.type = "audio";
                if ($scope.messageDetils.length > 0) {
                    console.log(new Date().getTime() - $scope.messageDetils[$scope.messageDetils.length - 1].time);
                    //判断最后一条消息的时间和当前时间相差时间
                    if (Math.abs(new Date().getTime() - $scope.messageDetils[$scope.messageDetils.length - 1].time) > 10 * 60 * 1000) {
                        msgObj.showTimeFlag = true;
                    } else {
                        msgObj.showTimeFlag = false;
                    }
                } else {
                    msgObj.showTimeFlag = true;
                }
                msgObj.sendTime = formatDate(new Date());
                $scope.messageDetils.push(msgObj);
                $scope.form.send_content = null;
                $ionicScrollDelegate.scrollBottom(true);
                fileUtil.upload(audioSrc, "audio", "/patient/user/file/upload.htm", $rootScope.token).then(function (ret) {
                    var extras = {type: 'audio', url: ret.url, audioTime: audioTime, fileId: ret.fileId};
                    $scope.sendFileMsg('audio', extras);
                }, function (error) {

                })
            }
        };


        /**
         * 播放自己发的语音
         * @type {null}
         */
        var tempIndex = null;
        $scope.audioPlay = function (index) {
            var current = document.getElementById("audio_" + index);
            var pre = null;
            if (tempIndex) {
                pre = document.getElementById("audio_" + tempIndex);
                if (!$("#zz_audio_" + tempIndex).hasClass("z_stop")) {
                    $("#zz_audio_" + tempIndex).addClass("z_stop");
                }
                pre.load();
            }
            if (preIndex) {
                if (!$("#zz_audio_" + preIndex).hasClass("z_stop")) {
                    $("#zz_audio_" + preIndex).addClass("z_stop");
                }
                $("#Faudio_" + preIndex)[0].load();

            }
            $("#zz_audio_" + index).removeClass("z_stop"); //动画开始
            current.play();
            var interval = $interval(function () {
                if (current.ended) {
                    $("#zz_audio_" + index).addClass("z_stop");
                    $interval.cancel(interval);
                }
            }, 100);

            tempIndex = index;
        };

        /**
         * 播放收到的语音消息
         * @param index
         * @constructor
         */
        var preIndex = null;
        $scope.FromAudioPlay = function (index) {
            console.log('index:', index);
            $("#point_" + index).hide();
            var time = $("#time_" + index).val();
            console.log("time:", time);
            WebSql.updateAudioStatus(time);
            var current = document.getElementById("Faudio_" + index);
            var pre = null;
            if (preIndex) {
                pre = document.getElementById("Faudio_" + preIndex);
                if (!$("#zz_audio2_" + preIndex).hasClass("z_stop")) {
                    $("#zz_audio2_" + preIndex).addClass("z_stop");
                }
                pre.load();
            }
            if (tempIndex) {
                if (!$("#zz_audio_" + tempIndex).hasClass("z_stop")) {
                    $("#zz_audio_" + tempIndex).addClass("z_stop");
                }
                $("#audio_" + tempIndex)[0].load();

            }
            $("#zz_audio2_" + index).removeClass("z_stop"); //动画开始
            current.play();
            var interval = $interval(function () {
                if (current.ended) {
                    $("#zz_audio2_" + index).addClass("z_stop");
                    $interval.cancel(interval);
                }
            }, 100);

            preIndex = index;

        }

        //回到健康页面
        $scope.goBack = function () {
            $("input").blur();
            $interval.cancel($scope.listenKeyBord);
//            if (is_playFinish) {
//                $interval.cancel(is_playFinish);
//            }
            //--新
//            var param = $cacheFactory.get($stateParams.backUrl);
            var param = $cacheFactory.get("add_doctor");
            var param2 = $cacheFactory.get("doctor_consult");
            var sp2 = param2.get('stateParams');
            var sp = null;
            //如果不在页面参数则设置为空串
            if (param) {
                sp = param.get('stateParams');
                console.log("sp:", sp);
                if (!sp) {
                    sp = {};
                }
            } else {
//                sp = {};
                sp = {backUrl: 'doctor_consult'};
            }

            $timeout(function () {
                $ionicNativeTransitions.stateGo(sp.backUrl, sp2, {
                    "type": "slide",
                    "direction": "right",
                    "duration": 500
                });
            }, 400);

        };
        /**
         * 收到物理返回键按钮事件
         */
        var c_name = $state.current.name;
        $scope.$on(c_name + '_HARDWARE_BACK', function () {
            $scope.goBack();
        });
        //显示图片详细
        $scope.showImage = function (imageUrl) {
            var cache = $cacheFactory.get('showBigImage');
            if (!cache) {
                cache = $cacheFactory('showBigImage');
            }
            var imageArray = new Array();
            var urlObj = new Object();
            urlObj.url = imageUrl;
            imageArray.push(urlObj);
            cache.put("images", imageArray);
            $ionicNativeTransitions.stateGo('z_show_img', {backUrl: 'z_message_chat'}, {
                "type": "fade",
                "duration": 400// in milliseconds (ms), default 400
            });
        };
        var count = 10;
        var sendTime = new Date().getTime();
        $scope.loadMore = function () {
            $scope.form.load = true;
            console.log("加载聊天记录");
            WebSql.loadChatMsg($stateParams.doctorId, count, sendTime, $rootScope.user.userId).then(function (data) {
                if (data.length <= 0) {
                    console.log("没有历史记录");
                } else {
                    console.log("加载成功");
                    sendTime = data[0].time;
                    $scope.messageDetils = data.concat($scope.messageDetils);
                }
                $timeout(function () {
                    $scope.$broadcast('scroll.refreshComplete');
                }, 1000)
            }, function (error) {
            });
        };
        $scope.$on('scroll.refreshComplete', function () {
            $scope.form.load = false;
        });

        /**
         * 根据录音时间的长短显示录音条的长度
         * @param time
         * @returns {number}
         */
        $scope.getAudioWidth = function (time) {
            if (isContains(time, "″")) {
                var end = time.lastIndexOf("″");
                time = time.substring(0, end);
                time = parseInt(time);
//                console.log('time',time);
            }
            if (time < 10) {
                return 70;
            } else if (time >= 10 && time < 20) {
                return 90;
            } else if (time >= 20 && time < 30) {
                return  110;
            } else if (time >= 30 && time < 40) {
                return  130;
            } else if (time >= 40 && time < 50) {
                return  110;
            } else if (time >= 50) {
                return  150;
            }
        };
        $scope.loadMore();
        /*        $ionicScrollDelegate.scrollTop(true);
         $ionicScrollDelegate.scrollBottom(true);*/
        $timeout(function () {
            $ionicScrollDelegate.scrollBottom(true);
            //  $ionicScrollDelegate.scrollBy(0, $rootScope.screenHeight);
        }, 300);

        /**
         * 医生详细信息
         */
        $scope.doctorInfo = function (doctorId) {
            $ionicNativeTransitions.stateGo('doctor_data', {backUrl: 'z_message_chat', doctorId: doctorId}, {
                "type": "slide",
                "direction": "right",
                "duration": 500
            });
        }

        $scope.videoWithOther = function () {
            //若未登录，给它登录一下
            if (!$rootScope.ImVideo_login_flag) {
                $rootScope.initImVideo();
            }
            console.info("视屏通话");
            var data2 = {
                touserId: $scope.user.serviceId,
                touserName: $scope.user.name
            };

            EasemobPlugin.videoCall(data2, function (ret, err) {
                if (ret) {
                    alert("success");
                    console.info("ret:", ret);
                }
                if (err) {
                    alert("error");
                    console.error(err);
                }
            });
        };
    })
    .controller('showImageController', function ($scope, $rootScope, $ionicNativeTransitions, $cacheFactory, $state, $ionicSlideBoxDelegate, $ionicScrollDelegate, $stateParams) {
        var cache = $cacheFactory.get('showBigImage');
        if (!cache) {
            cache = $cacheFactory('showBigImage');
        }
        $scope.images = cache.get('images');
        $scope.goBack = function () {
            console.log("回退");
            //取出回退页面跳转参数
            var param = $cacheFactory.get($stateParams.backUrl);
            var sp = null;
            //如果不在页面参数则设置为空串
            if (param) {
                sp = param.get('stateParams');
                if (!sp) {
                    sp = {};
                }
            } else {
                sp = {};
            }
            $ionicNativeTransitions.stateGo($stateParams.backUrl, sp, {
                "type": "slide",
                "direction": "right",
                "duration": 500
            });
//            $ionicNativeTransitions.stateGo('z_message_chat', {backUrl: 'tab.health'}, {
//                "type": "fade",
//                "duration": 400// in milliseconds (ms), default 400
//            });
        };
        $scope.enableSlide = function (flag) {
            if (flag) {
                var index = $ionicSlideBoxDelegate.$getByHandle('imghandle').currentIndex();
                var count = $ionicSlideBoxDelegate.$getByHandle('imghandle').slidesCount() - 1;
                if (index == 0 || index == count) {
                    $ionicSlideBoxDelegate.$getByHandle('imghandle').enableSlide(false);
                    return;
                }
                var si = $ionicScrollDelegate.$getByHandle('picHandle_' + index)._instances;
                console.log(si);
                var d = null;
                for (var i = si.length - 1; i >= 0; i--) {
                    if (si[i].$$delegateHandle == 'picHandle_' + index) {
                        d = si[i];
                        break;
                    }
                }
                var zoomLevel = d.getScrollView().__zoomLevel;
                if (zoomLevel == 1) {
                    $ionicSlideBoxDelegate.$getByHandle('imghandle').enableSlide(true);
                }
            } else {
                $ionicSlideBoxDelegate.$getByHandle('imghandle').enableSlide(false);
            }
        };
    });


