//药物服用计划模块
//闹钟模块
angular.module('Plan', ['Dom', 'File'])
    //文件系统
    .factory('Plan', function ($http, $rootScope, $q, $cacheFactory, $cordovaLocalNotification, $interval, Mes, $timeout, MesDom, $cordovaFile, FileServer) {
        var today_ymd = date2str(new Date(), 'yyyy-MM-dd');
        var notification_id = 1;
        var map = {};
        var scan_reset_interval = null;
        var minute_interval = null;
        var alarm_log = "";
        //预置闹铃天数7天，修改为3天
        var set_day = 3;
        var set_interval = 3000;
        return {
            /**
             * 是否已过时段
             * @param time 服药时间
             * @returns {boolean}
             */
            is_over: function (time) {
                var ret = false;
                var date = new Date();
                var h = parseInt(time.split(':')[0]);
                var m = parseInt(time.split(':')[1]);

                var n_h = date.getHours();
                var n_m = date.getMinutes();
                if (n_h > h) {
                    ret = true;
                } else if (n_h < h) {
                    ret = false;
                } else {
                    if (n_m > m) {
                        ret = true;
                    } else {
                        ret = false;
                    }
                }
                return ret;
            },
            /**
             * 时段未到达
             * @param bucket 时段
             * @returns {boolean}
             */
            is_not_fetch: function (time) {
                //返回值
                var ret = false;
                var date = new Date();
                //服药小时
                var h = parseInt(time.split(':')[0]);
                //服药分钟
                var m = parseInt(time.split(':')[1]);
                //当前小时
                var n_h = date.getHours();
                //当前分钟
                var n_m = date.getMinutes();
                if (n_h < h) {
                    ret = true;
                } else if (n_h > h) {
                    ret = false;
                } else {
                    if (n_m < m) {
                        ret = true;
                    } else {
                        ret = false;
                    }
                }
                console.log('药品服用时间', h + ':' + m, '当前时间', n_h + ':' + n_m, '未到达', ret);
                return ret;
            },
            /**
             * 判断是否是今天
             * @param day 日期格式 '2016-03-03'
             * @returns {boolean}
             */
            is_today: function (day) {
                var ret = false;
                var today = date2str(new Date(), 'yyyy-MM-dd');
                if (today == day) {
                    ret = true;
                }
                console.log('判断是否是今天', day, today);
                return ret;
            },
            takeAll: function (date, time, planIds, toUser) {
                var q = $q.defer();
                var req = {
                    method: 'GET',
                    url: $rootScope.reqUrl + "/patient/user/medicine/take.htm",
                    params: {
                        token: $rootScope.token,
                        shouldTakeTime: time,
                        planIds: planIds,
                        method: 'all',
                        takeDate: date
                    },
                    timeout: 10000
                };
                $http(req).success(function (result) {
                    if (result.status) {
                        //服用药物广播数据构造方式 日期+服用时间+计划id 唯一确定药片dom id
//                        var take_data = {ymd: date, time: time, planIds: planIds, toUser: toUser};
//                        $rootScope.$broadcast('MEDICINE_TAKE', take_data);
                        if (window.cordova) {
                            FileServer.writeFile(date + '_take.txt', 'time:' + time + ' planId:' + planIds + ' OK\n');
                        }
                        q.resolve(result);
                    } else {
                        FileServer.writeFile(date + '_take.txt', 'time:' + time + ' planId:' + planIds + ' ERROR\n');
                        q.reject(result.message);
                    }
                }).error(function (result) {
                    FileServer.writeFile(date + '_take.txt', 'time:' + time + ' planId:' + planIds + ' ERROR\n');
                    q.reject("ERROR");
                });
                return q.promise;
            },
            take: function (date, time, planId, toUser) {
                var q = $q.defer();
                var req = {
                    method: 'GET',
                    url: $rootScope.reqUrl + "/patient/user/medicine/take.htm",
                    params: {
                        token: $rootScope.token,
                        shouldTakeTime: time,
                        planId: planId,
                        method: 'one',
                        takeDate: date
                    },
                    timeout: 10000
                };
                $http(req).success(function (result) {
                    if (result.status) {
                        //服用药物广播数据构造方式 日期+服用时间+计划id 唯一确定药片dom id
//                        var take_data = {ymd: date, time: time, planIds: planId, toUser: toUser};
//                        $rootScope.$broadcast('MEDICINE_TAKE', take_data);
                        FileServer.writeFile(date + '_take.txt', 'time:' + time + ' planId:' + planId + ' OK\n');
                        q.resolve(result);
                    } else {
                        FileServer.writeFile(date + '_take.txt', 'time:' + time + ' planId:' + planId + ' ERROR\n');
                        q.reject(result.message);
                    }
                }).error(function (result) {
                    FileServer.writeFile(date + '_take.txt', 'time:' + time + ' planId:' + planId + ' ERROR\n');
                    q.reject("ERROR");
                });
                return q.promise;
            },
            findRemind: function () {
                var key = 'remind';
                var q = $q.defer();
                var req = {
                    method: 'GET',
                    url: $rootScope.reqUrl + "/baike/query.htm",
                    params: {
                        id: Math.floor(Math.random() * 10) + 1
                    },
                    timeout: 3000
                };
                $http(req).success(function (result) {
                    if (result.status) {
                        q.resolve(result);
                        localStorage.setItem(key, JSON.stringify(result));
                    } else {
                        q.reject(result.message);
                    }
                }).error(function (result) {
                    var ret = localStorage.getItem(key);
                    if (ret) {
                        q.resolve(eval("(" + ret + ")"));
                    } else {
                        q.reject("ERROR");
                    }
                });
                return q.promise;
            },
            /**
             * 查询全部
             * @param plan 新建计划
             * @returns {*}
             */
            findAll: function (plan) {
                var key = 'plans';
                var user_cache = $cacheFactory.get('user');
                if (!user_cache) {
                    user_cache = $cacheFactory('user');
                }
                var q = $q.defer();//固定用法，设置回调问题 then
                var req = {
                    method: 'GET',
                    url: $rootScope.reqUrl + "/patient/user/medicine/plan/query.htm",
                    params: {
                        token: $rootScope.token,
                        method: 'all'
                    },
                    timeout: 2000
                };
                $http(req).success(function (result) {
                    if (result.status) {
                        q.resolve(result.data);
                        user_cache.put('plans', result.data.list);//放在缓存中
                        if (result.data.delayList) {
                            user_cache.put('delay_plans', result.data.delayList);
                        }
                        localStorage.setItem(key, JSON.stringify(result.data));//放在本地缓存中
                    } else {
                        q.reject(result.message);
                    }
                }).error(function (result) {
                    var ret = localStorage.getItem(key);
                    if (ret) {
                        ret = eval("(" + ret + ")");
                        if (plan) {
                            ret.list.push(plan);
                            localStorage.setItem(key, JSON.stringify(ret));
                        }
                        user_cache.put('plans', ret.list);
                        q.resolve(ret);
                    } else {
                        q.reject("ERROR");
                    }
                });
                return q.promise;
            },
            /**
             * 查询历史用药
             * @returns {*}
             */
            findHisDrug: function (toUser) {
                var q = $q.defer();//固定用法，设置回调问题 then
                var req = {
                    method: 'GET',
                    url: $rootScope.reqUrl + "/patient/user/medicine/plan/hisDrugInfo.htm",
                    params: {
                        toUser:toUser,
                        token: $rootScope.token
                    },
                    timeout: 2000
                };
                $http(req).success(function (result) {
                    if (result.status) {
                        q.resolve(result.data);
                    } else {
                        q.reject(result.message);
                    }
                }).error(function (result) {
                    q.reject("ERROR");
                });
                return q.promise;
            },
            /**
             * 用药日历信息
             * @returns {*}
             */
            calendarInfo: function (medicineId) {
                var q = $q.defer();//固定用法，设置回调问题 then
                var req = {
                    method: 'GET',
                    url: $rootScope.reqUrl + "/patient/user/medicine/plan/calendarInfo.htm",
                    params: {
                        token: $rootScope.token,
                        medicineId:medicineId
                    },
                    timeout: 2000
                };
                $http(req).success(function (result) {
                    if (result.status) {
                        q.resolve(result.data);
                    } else {
                        q.reject(result.message);
                    }
                }).error(function (result) {
                    q.reject("ERROR");
                });
                return q.promise;
            },
            //将各个时间段的提醒都放在一个集合里面，成为一簇
            setAlarm: function (plans) {
                var p = null;
                var now = new Date().getTime();
                for (var i in plans) {
                    //提取一条服药计划对象
                    p = plans[i];
                    //提取不同时段如 08:00 10:00 12:00
                    var times = p.takeTimes;
                    //遍历各条计划的各个时段
                    for (var j in times) {
                        var tm = times[j];
                        //TODO 逻辑存在问题
                        var t = tm.firstAt;
                        if (now > t) {
                            t = t + 60 * 24 * (p.step + 1) * 60 * 1000;
                        }
                        //计划提醒键
                        var key = p.id + '_' + tm.time;
                        map[key] = notification_id;
                        //判断铃声开关
                        var ringUrl = null;
                        if ($rootScope.sound.audio) {
                            ringUrl = $rootScope.sound.ring;
                        }
                        $cordovaLocalNotification.schedule({
                            id: notification_id,
                            title: '吃药时间到了',
                            text: '您的药' + p.medicineName + '该吃了',
                            at: new Date(t),
                            sound: ringUrl,
                            data: {
                                plan: p,
                                at: tm
                            }
                        }).then(function (result) {
                            //alert(result);
                        });
                        notification_id++;
                    }
                }
            },
            /**
             * 清除一个提醒
             * @param id
             */
            clear_one: function (id) {
                //alert('闹铃id' + id);
                $cordovaLocalNotification.clear(id).then(function (data) {
                    //alert(data);
                });
            },
            clear_all: function () {
                $cordovaLocalNotification.clearAll().then(function (data) {
                    //alert(JSON.stringify(data));
                });
            },
            cancelAlarm: function () {
                notification_id = 1;
                map = {};
                $cordovaLocalNotification.cancelAll().then(function (data) {
                });
            },
            /**
             * 获取提醒内容
             * @param data
             * @returns {string}
             */
            get_alarm_text: function (data) {
                var text = '您的药';
                if (data instanceof Array) {
                    for (var i in data) {
                        text = text + data[i].plan.medicineName + '、';
                    }
                    text = text.substr(0, text.length - 1);
                } else {
                    text = text + data.plan.medicineName;
                }
                text = text + '服用时间到了';
                //alert(text);
                return text;
            },
            /**
             * 重置闹钟
             */
            resetAlarm: function (plan) {
                //将当前对象复制为变量
                console.debug('plan:', plan);
                today_ymd = date2str(new Date(), 'yyyy-MM-dd');
                notification_id = 1;
                map = {};
                var p_this = this;
                //重新设置闹铃
                p_this.findAll(plan).then(function (data_1) {
                    console.debug("查询到所有闹钟：", data_1);
                    if (window.cordova) {
                        $cordovaLocalNotification.cancelAll().then(function (data) {
                            //p_this.set_today_alarm(data_1.list, false);
                            p_this.set_many_day_alarm(data_1.list);
                            p_this.set_delay_plan_alarm(data_1.delayList);
                        });
                    }
                }, function (error) {

                });
            },


            /**
             * 推迟闹铃
             * @param alarm 提醒对象
             * @param minute 分钟
             */
            delay_alarm: function (alarm, minute) {
                var today_date = new Date();
                var today_day = date2str(today_date, 'yyyy-MM-dd');
                var count = null;
                var time = null;
                var data = null;
                if (alarm instanceof  Array) {
                    data = {
                        list: alarm,
                        is_list: true,
                        delay: 'HAVE_ALARM'
                    };
                    time = alarm[0].at.time;
                    count = alarm.length;
                } else {
                    data = {
                        plan: alarm.plan,
                        at: alarm.at,
                        delay: 'HAVE_ALARM'
                    };
                    time = alarm.at.time;
                    count = 1;
                }
                var delayAt = new Date().getTime() + minute * 60 * 1000;
                //判断铃声开关
                var ringUrl = null;
                if ($rootScope.sound.audio) {
                    ringUrl = $rootScope.sound.ring;
                }
                $cordovaLocalNotification.schedule({
                    id: notification_id,
                    title: '药物提醒',
                    text: this.get_alarm_text(alarm),
                    at: new Date(delayAt),
                    sound: ringUrl,
                    data: data
                }).then(function (result) {
                    var log_file = today_day + '_at_' + time.replace(":", "") + '.txt';
                    var log_data = 'delay:' + date2str(today_date, 'hh:mm:ss') + ' count:' + count + ' ' + result + '\n';
                    FileServer.writeFile(log_file, log_data);
                });
                notification_id++;
            },
            /**
             * 推迟未到达执行时间的闹钟
             * @param p 计划
             * @param time 执行时间
             * @param minute 推迟分钟数
             */
            delay_not_fetch: function (p, time, minute) {
                var tms = p.takeTimes;
                var tm = null;
                for (var i in tms) {
                    if (tms[i].time == time) {
                        tm = tms[i];
                        break;
                    }
                }
                var date = new Date();
                date.setHours(parseInt(time.split(':')[0]));
                date.setMinutes(parseInt(time.split(':')[1]));
                date.setSeconds(0);
                var new_date = new Date(date.getTime() + minute * 60 * 1000);
                var key = p.id + '_' + tm.time;
                var id = map[key];
                //判断铃声开关
                var ringUrl = null;
                if ($rootScope.sound.audio) {
                    ringUrl = $rootScope.sound.ring;
                }
                $cordovaLocalNotification.update({
                    id: id,
                    title: '提醒吃药',
                    text: '提醒吃药',
                    at: new_date,
                    sound: ringUrl,
                    data: {
                        plan: p,
                        at: tm,
                        //推迟未响闹钟
                        delay: 'NOT_FETCH'
                    }
                }).then(function (result) {
                    //alert(result);
                });
            },

            cancel_alarm: function (id) {
                $cordovaLocalNotification.cancel(id).then(function (data) {
                    //alert('取消闹钟成功');
                });
            },
            /**
             *推迟程序死前设置的闹钟
             * @param set_date
             * @param alarm
             */
            set_one_alarm: function (set_date, alarm) {
                var alarm_text = '您的' + alarm.plan.medicineName + '用药时间到了';
                var ringUrl = null;
                if ($rootScope.sound.audio) {
                    ringUrl = $rootScope.sound.ring;
                }
                $cordovaLocalNotification.schedule({
                    id: notification_id,
                    title: '药物提醒',
                    text: alarm_text,
                    at: set_date,
                    sound: ringUrl,
                    data: alarm
                }).then(function (result) {
                    //alert(result);
                });
                notification_id++;
            },
            /**
             *应用程序杀掉之后，重启设置的推迟闹钟
             * @param plans
             */
            set_delay_plan_alarm: function (plans) {
                for (var z in plans) {
                    var d = plans[z];
                    var date = new Date().getTime();
                    //设置推迟时间戳
                    var setTime = new Date(d.phoneLocalTime).getTime() + (d.delayMinute * 60 * 1000);
                    console.log("时间判断", date + "," + setTime);
                    if (date < setTime) {
                        var tt = d.plan.takeTimes;
                        for (var j in tt) {
                            var t = tt[j];
                            if (t.time == d.delayTime) {
                                //包装推迟计划
                                var alarm = {
                                    plan: d.plan,
                                    at: t,
                                    delay: true
                                };
                                this.set_one_alarm(new Date(setTime), alarm);
                                break;
                            }
                        }
                    }
                }
            },

            /**
             * 设置一天的闹铃提醒
             * @param plans 计划列表
             * @param day 日期字符串
             */
            set_one_day_alarm: function (day, plans) {
                var alarm_map = {};
                for (var i in plans) {
                    //提取一条服药计划对象
                    var p = plans[i];
                    //alert(p.medicineName);
                    //判断当天计划是否有效
                    if (this.is_effect_in(day, p)) {
                        //alert('一条计划');
                        //提取不同时段如 08:00 10:00 12:00
                        var tt = p.takeTimes;
                        //遍历各条计划的各个时段
                        for (var j in tt) {
                            var t = tt[j];
                            //通过map对相同时间点的提醒单位通过数组进行聚合
                            if (!alarm_map[t.time]) {
                                alarm_map[t.time] = new Array();
                            }
                            var alarm = {
                                plan: p,
                                at: tt[j]
                            };
                            alarm_map[t.time].push(alarm);
                        }
                    }
                }
                var today_date = new Date();
                var today_day = date2str(today_date, 'yyyy-MM-dd');
                //判断是否是今天的闹铃提醒
                if (today_day != day) {
                    console.log('不是今天');
                    for (var alarm_time in alarm_map) {
                        this.set_alarm_list(day, alarm_time, alarm_map[alarm_time]);
                    }
                } else {
                    console.log('是今天');
                    for (var alarm_time in alarm_map) {
                        if (this.is_not_fetch(alarm_time)) {
                            this.set_alarm_list(day, alarm_time, alarm_map[alarm_time]);
                        }
                    }
                }
            },
            //设置多天闹铃
            set_many_day_alarm: function (plans, continous) {
                var today_date = new Date();
                if (continous) {
                    for (var i = 0; i < set_day; i++) {
                        var date = new Date(today_date.getTime() + i * 3600 * 24 * 1000);
                        this.set_one_day_alarm(date2str(date, 'yyyy-MM-dd'), plans);
                    }
                } else {
                    this.set_index = 0;
                    var p_this = this;
                    //使用闭包解决interval传参问题
                    function set_func(pointer) {
                        return function () {
                            console.log(pointer.set_index);
                            var date = new Date(today_date.getTime() + pointer.set_index * 3600 * 24 * 1000);
                            pointer.set_one_day_alarm(date2str(date, 'yyyy-MM-dd'), plans);
                            pointer.set_index++;
                        }
                    }

                    $interval(set_func(p_this), set_interval, set_day);
                }
            },
            //根据闹铃对象列表设置计划
            //set_alarm_list: function (day, time, alarm_list) {
            set_alarm_list: function (day, time, alarm_list) {
                var date = new Date(day);
                date.setHours(parseInt(time.split(':')[0]));
                date.setMinutes(parseInt(time.split(':')[1]));
                date.setSeconds(0);
                date.setMilliseconds(0);
                //alert('闹铃时刻' + today_date);
                var alarm_text = '您的药';
                for (var i in alarm_list) {
                    alarm_text = alarm_text + alarm_list[i].plan.medicineName + ',';
                }
                alarm_text = alarm_text.substr(0, alarm_text.length - 1);
                alarm_text = alarm_text + '服用时间到了';
                //判断铃声开关
                var ringUrl = null;
                if ($rootScope.sound.audio) {
                    ringUrl = $rootScope.sound.ring;
                }
                $cordovaLocalNotification.schedule({
                    id: notification_id,
                    title: '药物提醒',
                    text: alarm_text,
                    at: date,
                    sound: ringUrl,
                    data: {
                        //提醒列表
                        list: alarm_list,
                        is_list: true
                    }
                }).then(function (result) {
                    //日志文件命名规则  (日期)_at_(提醒时间).txt
                    var log_file = day + '_at_' + time.replace(":", "") + '.txt';
                    //日志文件内容 set:(设置时间) count:(药品数量) 设置结果 方式:追加
                    var log_data = 'set:' + date2str(new Date(), 'yyyy-MM-dd hh:mm:ss') + ' count:' + alarm_list.length + ' ' + result + '\n';
                    FileServer.writeFile(log_file, log_data);
                });
                notification_id++;
            },
            /**
             * 根据服药计划设置今天的闹钟
             * @param plans
             * @param bool_alarm_past 过去的时间点是否提示
             */
            set_today_alarm: function (plans, bool_alarm_past) {
                alarm_log = "";
                //alert('设置今天的闹铃提醒');
                var alarm_map = {};
                for (var i in plans) {
                    //提取一条服药计划对象
                    var p = plans[i];
                    //alert(p.medicineName);
                    //判断当天计划是否有效
                    if (this.is_effect_in_today(p)) {
                        //alert('一条计划');
                        //提取不同时段如 08:00 10:00 12:00
                        var tt = p.takeTimes;
                        //遍历各条计划的各个时段
                        for (var j in tt) {
                            var t = tt[j];
                            //通过map对相同时间点的提醒单位通过数组进行聚合
                            if (alarm_map[t.time]) {
                                console.log('相同时刻存在提醒', t.time);
                            } else {
                                alarm_map[t.time] = new Array();
                                console.log('相同时段未有提醒', t.time);
                            }
                            var alarm = {
                                plan: p,
                                at: tt[j]
                            };
                            alarm_map[t.time].push(alarm);
                        }
                    }
                }
                //判断是否提醒已过闹钟
                if (bool_alarm_past) {
                    for (var alarm_time in alarm_map) {
                        this.set_today_alarm_list(alarm_time, alarm_map[alarm_time]);
                    }
                }
                else {
                    for (var alarm_time in alarm_map) {
                        if (this.is_not_fetch(alarm_time)) {
                            this.set_today_alarm_list(alarm_time, alarm_map[alarm_time]);
                        }
                    }
                }
                //alert("111");
                var today_day = date2str(new Date(), 'yyyyMMdd');
                //alert("内容：" + alarm_log);
                FileServer.writeFile(today_day + ".txt", alarm_log);

            },
            /**
             * 保存闹钟对象
             * @param time 时间点 如08:00
             * @param alarm_list 闹铃列表
             */
            set_today_alarm_list: function (time, alarm_list) {
                //alert(time);
                var today_date = new Date();
                var today_day = date2str(today_date, 'yyyy-MM-dd');
                var h = today_date.getHours();
                var m = today_date.getMinutes();
                var s = today_date.getSeconds();
                today_date.setHours(parseInt(time.split(':')[0]));
                today_date.setMinutes(parseInt(time.split(':')[1]));
                today_date.setSeconds(0);
                today_date.setMilliseconds(0);
                //alert('闹铃时刻' + today_date);
                var alarm_text = '您的药';
                for (var i in alarm_list) {
                    alarm_text = alarm_text + alarm_list[i].plan.medicineName + ',';
                }
                alarm_text = alarm_text.substr(0, alarm_text.length - 1);
                alarm_text = alarm_text + '服用时间到了';
                //判断铃声开关
                var ringUrl = null;
                // alert('sound-pre');
                if ($rootScope.sound.audio) {
                    ringUrl = $rootScope.sound.ring;
                }
                //alert('sound-a');
                if (window.cordova) {
                    //alert("------------be" + alarm_log);
                    alarm_log = alarm_log + alarm_text + "," + today_date + ';';
                    //alert("------------" + alarm_log);
                    $cordovaLocalNotification.schedule({
                        id: notification_id,
                        title: '药物提醒',
                        text: alarm_text,
                        at: today_date,
                        sound: ringUrl,
                        data: {
                            //提醒列表
                            list: alarm_list,
                            is_list: true
                        }
                    }).then(function (result) {
                        //日志文件命名规则  (日期)_at_(提醒时间).txt
                        var log_file = today_day + '_at_' + time.replace(":", "") + '.txt';
                        //日志文件内容 set:(设置时间) count:(药品数量) 设置结果 方式:追加
                        var log_data = 'set:' + h + ":" + m + ":" + s + ' count:' + alarm_list.length + ' ' + result + '\n';
                        FileServer.writeFile(log_file, log_data);
                    });
                    notification_id++;
                } else {
                    console.log(alarm_list);
                }
            },
            /**
             * 测试是否有效
             * @param plan 计划
             * @param day 日期
             * @returns {boolean}
             */
            is_effect_in: function (day, plan) {
                var ret = false;
                var date = new Date(day);
                var begin_day = plan.beginYmd;
                if (plan.term == 'OneDay') {
                    //单日服药 如果开始时间为今天认为是今天的服药计划
                    if (begin_day == day) {
                        ret = true;
                    }
                } else if (plan.term == 'EveryDay') {
                    //每日服药 如果按步长计算今日应当服药则认为是今天的服药计划
                    var begin_date = new Date(plan.beginYmd);
                    if (date >= begin_date) {
                        //今天已经是计划开始执行日期
                        //计算天数差值
                        var diff_day = Math.ceil((date - begin_date) / (24 * 3600 * 1000));
                        //根据取余数判断今天是否是服药计划天数
                        if (diff_day % (plan.step + 1) == 0) {
                            ret = true;
                        }
                    } else {
                        //计划未到执行日期
                    }
                } else if (plan.term == 'Series') {
                    //每日服药 如果按步长计算今日应当服药则认为是今天的服药计划
                    var begin_date = new Date(plan.beginYmd);
                    var end_date = new Date(plan.endYmd);
                    //大于开始日期小于结束日期
                    if (date >= begin_date && date < end_date) {
                        //今天已经是计划开始执行日期
                        //计算天数差值
                        var diff_day = Math.ceil((date - begin_date) / (24 * 3600 * 1000));
                        //根据取余数判断今天是否是服药计划天数
                        if (diff_day % (plan.step + 1) == 0) {
                            ret = true;
                        }
                    } else {
                        //计划未到执行日期
                    }
                }
                console.log('判断计划是否在今天有效', plan);
                console.log('结果', ret);
                return ret;
            },
            /**
             * 判断
             * @param plan
             */
            is_effect_in_today: function (plan) {
                var ret = false;
                var today = date2str(new Date(), 'yyyy-MM-dd');
                var begin_day = plan.beginYmd;
                if (plan.term == 'OneDay') {
                    //单日服药 如果开始时间为今天认为是今天的服药计划
                    if (begin_day == today) {
                        ret = true;
                    }
                } else if (plan.term == 'EveryDay') {
                    //每日服药 如果按步长计算今日应当服药则认为是今天的服药计划
                    var today_date = new Date(today);
                    var begin_date = new Date(plan.beginYmd);
                    if (today_date >= begin_date) {
                        //今天已经是计划开始执行日期
                        //计算天数差值
                        var diff_day = Math.ceil((today_date - begin_date) / (24 * 3600 * 1000));
                        //根据取余数判断今天是否是服药计划天数
                        if (diff_day % (plan.step + 1) == 0) {
                            ret = true;
                        }
                    } else {
                        //计划未到执行日期
                    }
                } else if (plan.term == 'Series') {
                    //每日服药 如果按步长计算今日应当服药则认为是今天的服药计划
                    var today_date = new Date(today);
                    var begin_date = new Date(plan.beginYmd);
                    var end_date = new Date(plan.endYmd);
                    //大于开始日期小于结束日期
                    if (today_date >= begin_date && today_date < end_date) {
                        //今天已经是计划开始执行日期
                        //计算天数差值
                        var diff_day = Math.ceil((today_date - begin_date) / (24 * 3600 * 1000));
                        //根据取余数判断今天是否是服药计划天数
                        if (diff_day % (plan.step + 1) == 0) {
                            ret = true;
                        }
                    } else {
                        //计划未到执行日期
                    }
                }
                console.log('判断计划是否在今天有效', plan);
                console.log('结果', ret);
                return ret;
            },
            /**
             * 重设今天闹钟
             */
            reset_today_alarm: function () {
                today_ymd = date2str(new Date(), 'yyyy-MM-dd');
                var p_this = this;
                //alert('重设今天闹钟');
                var user_cache = $cacheFactory.get('user');
                //alert('用户缓存' + JSON.stringify(user_cache));
                var plans = user_cache.get('plans');
                //alert('计划缓存' + JSON.stringify(plans));
                if (plans) {
                    //alert('重设今天闹钟');
                    $cordovaLocalNotification.cancelAll().then(function (data) {
                        notification_id = 1;
                        //alert('取消全部闹钟');
                        p_this.set_today_alarm(plans, true);
                    }, function (error) {
                    });
                }
            },
//用组合做代理
            deal_alarm_trigger: function (ymd, data) {
                MesDom.deal_alarm_trigger(ymd, data);
            },
//处理服药
            deal_take_medicine: function (data) {
                var mes = Mes.findOneDayMesByYmd(data.ymd);
                //当天消息获取
                var ids = data.planIds.split(',');
                for (var i in ids) {
                    var planId = ids[i];
                    MesDom.deal_take_medicine(data);
                }
            },
//分钟级扫描任务
            start_minute_interval: function () {
                var p_this = this;
                minute_interval = $interval(function () {
                    //检测屏幕高度
                    if (document.documentElement.clientHeight > 0) {
                        $rootScope.screenHeight = document.documentElement.clientHeight;
                    }
                    var d = new Date();
                    var h = d.getHours();
                    var m = d.getMinutes();
                    var s = d.getSeconds();
                    // console.log('前台分钟级定时任务', '小时', h, '分钟', m, '秒', s);
                    //判断是否应该重新设定闹钟
//                    if (today_ymd != date2str(d, 'yyyy-MM-dd')) {
//                        //alert("目前" + today_ymd);
//                        //alert('新的' + date2str(d, 'yyyy-MM-dd'));
//                        //alert('重设今天闹钟');
//                        today_ymd = date2str(d, 'yyyy-MM-dd');
//                        p_this.reset_today_alarm();
//                    }
                    if (h == 0 && m == 0 && s == 0) {
                        $rootScope.$broadcast('RELOAD_MESSAGE');
                    } else if (h == 6 && m == 0 && s == 0) {
                        $rootScope.$broadcast('RELOAD_MESSAGE');
                    } else if (h == 12 && m == 0 && s == 0) {
                        $rootScope.$broadcast('RELOAD_MESSAGE');
                    } else if (h == 18 && m == 0 && s == 0) {
                        $rootScope.$broadcast('RELOAD_MESSAGE');
                    }
                }, 1000);
            },
            /**
             * 根据key值和列表获取提醒列表名称
             * @param list 列表
             * @param key 键值
             * @returns {string}
             */
            get_remind_message: function (list, key) {
                var ret = '';
                var num = 0;
                //if for循环执行速度 大于for循环执行速度
                if (key == 'plan_id') {
                    for (var i in list) {
                        var o = list[i];
                        if (o.take == 0 || o.take == 2) {
                            ret = ret + o.planId + ',';
                            num++;
                        }
                    }
                } else if (key == 'medicine_name') {
                    for (var i in list) {
                        var o = list[i];
                        //if (o.take == 0 || o.take == 2) {
                        ret = ret + o.medicine.medicineName + ',';
                        num++;
                        // }
                    }
                }
                if (num == 0) {
                    return null;
                }
                ret = ret.substr(0, ret.length - 1);
                return ret;
            }
        }
    })
;